from __future__ import annotations

from typing import Any, Optional

class DatasetBase:
    proto_desc: Any = ...
    dataset: Any = ...
    thread_num: int = ...
    filelist: Any = ...
    use_ps_gpu: bool = ...
    psgpu: Any = ...
    def __init__(self) -> None: ...
    def init(
        self,
        batch_size: int = ...,
        thread_num: int = ...,
        use_var: Any = ...,
        pipe_command: str = ...,
        input_type: int = ...,
        fs_name: str = ...,
        fs_ugi: str = ...,
        download_cmd: str = ...,
    ) -> None: ...
    def set_filelist(self, filelist: Any) -> None: ...

class InMemoryDataset(DatasetBase):
    fleet_send_batch_size: Any = ...
    is_user_set_queue_num: bool = ...
    queue_num: Any = ...
    parse_ins_id: bool = ...
    parse_content: bool = ...
    parse_logkey: bool = ...
    merge_by_sid: bool = ...
    enable_pv_merge: bool = ...
    merge_by_lineid: bool = ...
    fleet_send_sleep_seconds: Any = ...
    def __init__(self) -> None: ...
    def update_settings(self, **kwargs: Any) -> None: ...
    def init(self, **kwargs: Any) -> None: ...
    def set_date(self, date: Any) -> None: ...
    def tdm_sample(
        self,
        tree_name: Any,
        tree_path: Any,
        tdm_layer_counts: Any,
        start_sample_layer: Any,
        with_hierachy: Any,
        seed: Any,
        id_slot: Any,
    ) -> None: ...
    def load_into_memory(self, is_shuffle: bool = ...) -> None: ...
    def preload_into_memory(self, thread_num: Optional[Any] = ...) -> None: ...
    def wait_preload_done(self) -> None: ...
    def local_shuffle(self) -> None: ...
    def global_shuffle(self, fleet: Optional[Any] = ..., thread_num: int = ...) -> None: ...
    def release_memory(self) -> None: ...
    def get_memory_data_size(self, fleet: Optional[Any] = ...): ...
    def get_shuffle_data_size(self, fleet: Optional[Any] = ...): ...
    def slots_shuffle(self, slots: Any) -> None: ...

class QueueDataset(DatasetBase):
    def __init__(self) -> None: ...
    def init(self, **kwargs: Any) -> None: ...

class FileInstantDataset(DatasetBase):
    def __init__(self) -> None: ...
    def init(self, **kwargs: Any) -> None: ...

class BoxPSDataset(InMemoryDataset):
    boxps: Any = ...
    def __init__(self) -> None: ...
    def init(self, **kwargs: Any) -> None: ...
    def set_date(self, date: Any) -> None: ...
    def begin_pass(self) -> None: ...
    def end_pass(self, need_save_delta: Any) -> None: ...
    def wait_preload_done(self) -> None: ...
    def load_into_memory(self) -> None: ...
    def preload_into_memory(self) -> None: ...
    def slots_shuffle(self, slots: Any) -> None: ...
    def set_current_phase(self, current_phase: Any) -> None: ...
    def get_pv_data_size(self): ...
    def preprocess_instance(self) -> None: ...
    def postprocess_instance(self) -> None: ...



from __future__ import annotations

from typing import Any

DATA_URL: str
DATA_MD5: str
TOTAL_EN_WORDS: int
TOTAL_DE_WORDS: int
START_MARK: str
END_MARK: str
UNK_MARK: str

def reader_creator(tar_file: Any, file_name: Any, src_dict_size: Any, trg_dict_size: Any, src_lang: Any): ...
def train(src_dict_size: Any, trg_dict_size: Any, src_lang: str = ...): ...
def test(src_dict_size: Any, trg_dict_size: Any, src_lang: str = ...): ...
def validation(src_dict_size: Any, trg_dict_size: Any, src_lang: str = ...): ...
def get_dict(lang: Any, dict_size: Any, reverse: bool = ...): ...
def fetch() -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.incubate.fleet.base.fleet_base import DistributedOptimizer, Fleet
from paddle.fluid.incubate.fleet.parameter_server.distribute_transpiler.distributed_strategy import (
    TrainerRuntimeConfig as TrainerRuntimeConfig,
)

class FleetTranspiler(Fleet):
    startup_program: Any = ...
    main_program: Any = ...
    def __init__(self) -> None: ...
    def init(self, role_maker: Optional[Any] = ...) -> None: ...
    def init_worker(self) -> None: ...
    def init_server(self, model_dir: Optional[Any] = ..., **kwargs: Any) -> None: ...
    def run_server(self) -> None: ...
    def stop_worker(self) -> None: ...
    def distributed_optimizer(self, optimizer: Any, strategy: Optional[Any] = ...): ...
    def save_inference_model(
        self,
        executor: Any,
        dirname: Any,
        feeded_var_names: Any,
        target_vars: Any,
        main_program: Optional[Any] = ...,
        export_for_deployment: bool = ...,
    ) -> None: ...
    def save_persistables(
        self, executor: Any, dirname: Any, main_program: Optional[Any] = ..., **kwargs: Any
    ) -> None: ...

fleet: Any

class ParameterServerOptimizer(DistributedOptimizer):
    type: str = ...
    data_norm_name: Any = ...
    def __init__(self, optimizer: Any, strategy: Any, mode: Any = ...) -> None: ...
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ) -> None: ...
    def apply_gradients(self, params_grads: Any) -> None: ...
    def minimize(
        self,
        losses: Any,
        scopes: Optional[Any] = ...,
        startup_programs: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ) -> None: ...



from __future__ import annotations

from enum import Enum as Enum
from typing import Any, Optional

from .recorder import MetricsRecorder as MetricsRecorder
from .storable import Storable as Storable
from .tunable_space import TunableSpace as TunableSpace

class TrialStatus:
    RUNNING: str = ...
    COMPLETED: str = ...
    STOPPED: str = ...
    INVALID: str = ...

class Trial(Storable):
    def __init__(self, tunable_space: Any, trial_id: Optional[Any] = ..., status: Any = ...) -> None: ...
    @property
    def id(self): ...
    @property
    def space(self): ...
    @property
    def recorder(self): ...
    @property
    def score(self): ...
    @score.setter
    def score(self, score: Any) -> None: ...
    @property
    def best_step(self): ...
    @best_step.setter
    def best_step(self, best_step: Any) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status: Any) -> None: ...
    def summary(self) -> None: ...
    def get_state(self): ...
    def set_state(self, state: Any) -> None: ...
    @classmethod
    def from_state(cls, state: Any): ...



from __future__ import annotations

from typing import Any, Optional

def parse_args(): ...
def transform_and_save_int8_model(
    original_path: Any,
    save_path: Any,
    ops_to_quantize: str = ...,
    op_ids_to_skip: str = ...,
    debug: bool = ...,
    quant_model_filename: str = ...,
    quant_params_filename: str = ...,
    save_model_filename: str = ...,
    save_params_filename: Optional[Any] = ...,
) -> None: ...



from __future__ import annotations

import unittest
from typing import Any

class TestWeightQuantization(unittest.TestCase):
    weight_quantization_dir: str = ...
    cache_folder: Any = ...
    def setUp(self) -> None: ...
    def download_model(self, model_name: Any, data_url: Any, data_md5: Any): ...
    def cache_unzipping(self, target_folder: Any, zip_path: Any) -> None: ...
    def quantize_to_int(
        self,
        model_name: Any,
        model_data_url: Any,
        model_data_md5: Any,
        weight_bits: Any,
        quantizable_op_type: Any,
        weight_quantize_type: Any,
        generate_test_model: Any,
        threshold_rate: Any,
    ) -> None: ...
    def convert_to_fp16(
        self, model_name: Any, model_data_url: Any, model_data_md5: Any, model_filename: Any, params_filename: Any
    ) -> None: ...
    def run_models(
        self, model_dir: Any, model_filename: Any, params_filename: Any, input_data: Any, is_fp16_model: Any
    ): ...

class TestWeightQuantizationMobilenetv1(TestWeightQuantization):
    nocomb_model_name: str = ...
    nocomb_model_data_url: str = ...
    nocomb_model_data_md5: str = ...
    comb_model_name: str = ...
    comb_model_data_url: str = ...
    comb_model_data_md5: str = ...
    def test_weight_quantization_mobilenetv1_8bit_abs_max(self) -> None: ...
    def test_weight_quantization_mobilenetv1_8bit_channel_wise_abs_max(self) -> None: ...
    def test_weight_quantization_mobilenetv1_16bit_abs_max(self) -> None: ...
    def test_weight_quantization_mobilenetv1_16bit_channel_wise_abs_max(self) -> None: ...
    def test_mobilenetv1_fp16_combined(self) -> None: ...
    def test_mobilenetv1_fp16_nocombined(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from .layers import Layer

class Sequential(Layer):
    def __init__(self, *layers: Any) -> None: ...
    def __getitem__(self, name: Any): ...
    def __setitem__(self, name: Any, layer: Any) -> None: ...
    def __delitem__(self, name: Any) -> None: ...
    def __len__(self): ...
    def forward(self, input: Any): ...

class ParameterList(Layer):
    def __init__(self, parameters: Optional[Any] = ...) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __setitem__(self, idx: Any, param: Any) -> None: ...
    def __len__(self): ...
    def __iter__(self) -> Any: ...
    def append(self, parameter: Any): ...

class LayerList(Layer):
    def __init__(self, sublayers: Optional[Any] = ...) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __setitem__(self, idx: Any, sublayer: Any): ...
    def __delitem__(self, idx: Any) -> None: ...
    def __len__(self): ...
    def __iter__(self) -> Any: ...
    def append(self, sublayer: Any): ...
    def insert(self, index: Any, sublayer: Any) -> None: ...
    def extend(self, sublayers: Any): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.common_ops_import import *

from ..nn import Layer, Sequential

def yolo_loss(
    x: Any,
    gt_box: Any,
    gt_label: Any,
    anchors: Any,
    anchor_mask: Any,
    class_num: Any,
    ignore_thresh: Any,
    downsample_ratio: Any,
    gt_score: Optional[Any] = ...,
    use_label_smooth: bool = ...,
    name: Optional[Any] = ...,
    scale_x_y: float = ...,
): ...
def yolo_box(
    x: Any,
    img_size: Any,
    anchors: Any,
    class_num: Any,
    conf_thresh: Any,
    downsample_ratio: Any,
    clip_bbox: bool = ...,
    name: Optional[Any] = ...,
    scale_x_y: float = ...,
    iou_aware: bool = ...,
    iou_aware_factor: float = ...,
): ...
def deform_conv2d(
    x: Any,
    offset: Any,
    weight: Any,
    bias: Optional[Any] = ...,
    stride: int = ...,
    padding: int = ...,
    dilation: int = ...,
    deformable_groups: int = ...,
    groups: int = ...,
    mask: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...

class DeformConv2D(Layer):
    weight: Any = ...
    bias: Any = ...
    def __init__(
        self,
        in_channels: Any,
        out_channels: Any,
        kernel_size: Any,
        stride: int = ...,
        padding: int = ...,
        dilation: int = ...,
        deformable_groups: int = ...,
        groups: int = ...,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
    ): ...
    def forward(self, x: Any, offset: Any, mask: Optional[Any] = ...): ...

def read_file(filename: Any, name: Optional[Any] = ...): ...
def decode_jpeg(x: Any, mode: str = ..., name: Optional[Any] = ...): ...
def psroi_pool(
    x: Any, boxes: Any, boxes_num: Any, output_size: Any, spatial_scale: float = ..., name: Optional[Any] = ...
): ...

class PSRoIPool(Layer):
    output_size: Any = ...
    spatial_scale: Any = ...
    def __init__(self, output_size: Any, spatial_scale: float = ...) -> None: ...
    def forward(self, x: Any, boxes: Any, boxes_num: Any): ...

def roi_pool(
    x: Any, boxes: Any, boxes_num: Any, output_size: Any, spatial_scale: float = ..., name: Optional[Any] = ...
): ...

class RoIPool(Layer):
    def __init__(self, output_size: Any, spatial_scale: float = ...) -> None: ...
    def forward(self, x: Any, boxes: Any, boxes_num: Any): ...
    def extra_repr(self): ...

def roi_align(
    x: Any,
    boxes: Any,
    boxes_num: Any,
    output_size: Any,
    spatial_scale: float = ...,
    sampling_ratio: int = ...,
    aligned: bool = ...,
    name: Optional[Any] = ...,
): ...

class RoIAlign(Layer):
    def __init__(self, output_size: Any, spatial_scale: float = ...) -> None: ...
    def forward(self, x: Any, boxes: Any, boxes_num: Any, aligned: bool = ...): ...

class ConvNormActivation(Sequential):
    def __init__(
        self,
        in_channels: Any,
        out_channels: Any,
        kernel_size: int = ...,
        stride: int = ...,
        padding: Optional[Any] = ...,
        groups: int = ...,
        norm_layer: Any = ...,
        activation_layer: Any = ...,
        dilation: int = ...,
        bias: Optional[Any] = ...,
    ) -> None: ...

def nms(
    boxes: Any,
    iou_threshold: float = ...,
    scores: Optional[Any] = ...,
    category_idxs: Optional[Any] = ...,
    categories: Optional[Any] = ...,
    top_k: Optional[Any] = ...,
): ...



from __future__ import annotations

from .auto_parallel_amp import *
from .auto_parallel_fp16 import *
from .auto_parallel_gradient_merge import *
from .auto_parallel_recompute import *
from .auto_parallel_sharding import *
from .cpp_pass import *
from .fuse_all_reduce import *
from .pass_base import PassContext as PassContext
from .pass_base import PassManager as PassManager
from .pass_base import new_pass as new_pass
from .ps_server_pass import *
from .ps_trainer_pass import *



from __future__ import annotations

from typing import Any, Optional

def retinanet_target_assign(
    bbox_pred: Any,
    cls_logits: Any,
    anchor_box: Any,
    anchor_var: Any,
    gt_boxes: Any,
    gt_labels: Any,
    is_crowd: Any,
    im_info: Any,
    num_classes: int = ...,
    positive_overlap: float = ...,
    negative_overlap: float = ...,
): ...
def rpn_target_assign(
    bbox_pred: Any,
    cls_logits: Any,
    anchor_box: Any,
    anchor_var: Any,
    gt_boxes: Any,
    is_crowd: Any,
    im_info: Any,
    rpn_batch_size_per_im: int = ...,
    rpn_straddle_thresh: float = ...,
    rpn_fg_fraction: float = ...,
    rpn_positive_overlap: float = ...,
    rpn_negative_overlap: float = ...,
    use_random: bool = ...,
): ...
def sigmoid_focal_loss(x: Any, label: Any, fg_num: Any, gamma: float = ..., alpha: float = ...): ...
def detection_output(
    loc: Any,
    scores: Any,
    prior_box: Any,
    prior_box_var: Any,
    background_label: int = ...,
    nms_threshold: float = ...,
    nms_top_k: int = ...,
    keep_top_k: int = ...,
    score_threshold: float = ...,
    nms_eta: float = ...,
    return_index: bool = ...,
): ...
def iou_similarity(x: Any, y: Any, box_normalized: bool = ..., name: Optional[Any] = ...): ...
def box_coder(
    prior_box: Any,
    prior_box_var: Any,
    target_box: Any,
    code_type: str = ...,
    box_normalized: bool = ...,
    name: Optional[Any] = ...,
    axis: int = ...,
): ...
def polygon_box_transform(input: Any, name: Optional[Any] = ...): ...
def yolov3_loss(
    x: Any,
    gt_box: Any,
    gt_label: Any,
    anchors: Any,
    anchor_mask: Any,
    class_num: Any,
    ignore_thresh: Any,
    downsample_ratio: Any,
    gt_score: Optional[Any] = ...,
    use_label_smooth: bool = ...,
    name: Optional[Any] = ...,
    scale_x_y: float = ...,
): ...
def yolo_box(
    x: Any,
    img_size: Any,
    anchors: Any,
    class_num: Any,
    conf_thresh: Any,
    downsample_ratio: Any,
    clip_bbox: bool = ...,
    name: Optional[Any] = ...,
    scale_x_y: float = ...,
    iou_aware: bool = ...,
    iou_aware_factor: float = ...,
): ...
def bipartite_match(
    dist_matrix: Any, match_type: Optional[Any] = ..., dist_threshold: Optional[Any] = ..., name: Optional[Any] = ...
): ...
def target_assign(
    input: Any,
    matched_indices: Any,
    negative_indices: Optional[Any] = ...,
    mismatch_value: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def ssd_loss(
    location: Any,
    confidence: Any,
    gt_box: Any,
    gt_label: Any,
    prior_box: Any,
    prior_box_var: Optional[Any] = ...,
    background_label: int = ...,
    overlap_threshold: float = ...,
    neg_pos_ratio: float = ...,
    neg_overlap: float = ...,
    loc_loss_weight: float = ...,
    conf_loss_weight: float = ...,
    match_type: str = ...,
    mining_type: str = ...,
    normalize: bool = ...,
    sample_size: Optional[Any] = ...,
): ...
def prior_box(
    input: Any,
    image: Any,
    min_sizes: Any,
    max_sizes: Optional[Any] = ...,
    aspect_ratios: Any = ...,
    variance: Any = ...,
    flip: bool = ...,
    clip: bool = ...,
    steps: Any = ...,
    offset: float = ...,
    name: Optional[Any] = ...,
    min_max_aspect_ratios_order: bool = ...,
): ...
def density_prior_box(
    input: Any,
    image: Any,
    densities: Optional[Any] = ...,
    fixed_sizes: Optional[Any] = ...,
    fixed_ratios: Optional[Any] = ...,
    variance: Any = ...,
    clip: bool = ...,
    steps: Any = ...,
    offset: float = ...,
    flatten_to_2d: bool = ...,
    name: Optional[Any] = ...,
): ...
def multi_box_head(
    inputs: Any,
    image: Any,
    base_size: Any,
    num_classes: Any,
    aspect_ratios: Any,
    min_ratio: Optional[Any] = ...,
    max_ratio: Optional[Any] = ...,
    min_sizes: Optional[Any] = ...,
    max_sizes: Optional[Any] = ...,
    steps: Optional[Any] = ...,
    step_w: Optional[Any] = ...,
    step_h: Optional[Any] = ...,
    offset: float = ...,
    variance: Any = ...,
    flip: bool = ...,
    clip: bool = ...,
    kernel_size: int = ...,
    pad: int = ...,
    stride: int = ...,
    name: Optional[Any] = ...,
    min_max_aspect_ratios_order: bool = ...,
): ...
def anchor_generator(
    input: Any,
    anchor_sizes: Optional[Any] = ...,
    aspect_ratios: Optional[Any] = ...,
    variance: Any = ...,
    stride: Optional[Any] = ...,
    offset: float = ...,
    name: Optional[Any] = ...,
): ...
def roi_perspective_transform(
    input: Any,
    rois: Any,
    transformed_height: Any,
    transformed_width: Any,
    spatial_scale: float = ...,
    name: Optional[Any] = ...,
): ...
def generate_proposal_labels(
    rpn_rois: Any,
    gt_classes: Any,
    is_crowd: Any,
    gt_boxes: Any,
    im_info: Any,
    batch_size_per_im: int = ...,
    fg_fraction: float = ...,
    fg_thresh: float = ...,
    bg_thresh_hi: float = ...,
    bg_thresh_lo: float = ...,
    bbox_reg_weights: Any = ...,
    class_nums: Optional[Any] = ...,
    use_random: bool = ...,
    is_cls_agnostic: bool = ...,
    is_cascade_rcnn: bool = ...,
    max_overlap: Optional[Any] = ...,
    return_max_overlap: bool = ...,
): ...
def generate_mask_labels(
    im_info: Any,
    gt_classes: Any,
    is_crowd: Any,
    gt_segms: Any,
    rois: Any,
    labels_int32: Any,
    num_classes: Any,
    resolution: Any,
): ...
def generate_proposals(
    scores: Any,
    bbox_deltas: Any,
    im_info: Any,
    anchors: Any,
    variances: Any,
    pre_nms_top_n: int = ...,
    post_nms_top_n: int = ...,
    nms_thresh: float = ...,
    min_size: float = ...,
    eta: float = ...,
    return_rois_num: bool = ...,
    name: Optional[Any] = ...,
): ...
def box_clip(input: Any, im_info: Any, name: Optional[Any] = ...): ...
def retinanet_detection_output(
    bboxes: Any,
    scores: Any,
    anchors: Any,
    im_info: Any,
    score_threshold: float = ...,
    nms_top_k: int = ...,
    keep_top_k: int = ...,
    nms_threshold: float = ...,
    nms_eta: float = ...,
): ...
def multiclass_nms(
    bboxes: Any,
    scores: Any,
    score_threshold: Any,
    nms_top_k: Any,
    keep_top_k: Any,
    nms_threshold: float = ...,
    normalized: bool = ...,
    nms_eta: float = ...,
    background_label: int = ...,
    name: Optional[Any] = ...,
): ...
def locality_aware_nms(
    bboxes: Any,
    scores: Any,
    score_threshold: Any,
    nms_top_k: Any,
    keep_top_k: Any,
    nms_threshold: float = ...,
    normalized: bool = ...,
    nms_eta: float = ...,
    background_label: int = ...,
    name: Optional[Any] = ...,
): ...
def matrix_nms(
    bboxes: Any,
    scores: Any,
    score_threshold: Any,
    post_threshold: Any,
    nms_top_k: Any,
    keep_top_k: Any,
    use_gaussian: bool = ...,
    gaussian_sigma: float = ...,
    background_label: int = ...,
    normalized: bool = ...,
    return_index: bool = ...,
    name: Optional[Any] = ...,
): ...
def distribute_fpn_proposals(
    fpn_rois: Any,
    min_level: Any,
    max_level: Any,
    refer_level: Any,
    refer_scale: Any,
    rois_num: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def box_decoder_and_assign(
    prior_box: Any, prior_box_var: Any, target_box: Any, box_score: Any, box_clip: Any, name: Optional[Any] = ...
): ...
def collect_fpn_proposals(
    multi_rois: Any,
    multi_scores: Any,
    min_level: Any,
    max_level: Any,
    post_nms_top_n: Any,
    rois_num_per_level: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from typing import Any

from paddle.autograd import EagerPyLayer, PyLayer

from ...utils.recompute import check_recompute_necessary as check_recompute_necessary
from ...utils.recompute import detach_variable as detach_variable
from ..parallel_layers.random import get_rng_state_tracker as get_rng_state_tracker

FLOAT_TYPE_DICT: Any
PADDLE_TO_NUMBER: Any
NUMBER_TO_DTYPE: Any

def is_float_tensor(tensor: Any): ...
def get_tensor_dtype(dtype: Any): ...
def paddle_2_number(dtype: Any): ...
def number_2_dtype(number: Any): ...
def get_tensor_bytes(tensor: Any): ...

class _HPEagerRecomputeFunction(EagerPyLayer):
    @staticmethod
    def forward(ctx: Any, run_function: Any, all_outputs: Any, *args: Any): ...
    @staticmethod
    def backward(ctx: Any, *args: Any): ...

class _HPRecomputeFunction(PyLayer):
    @staticmethod
    def forward(ctx: Any, run_function: Any, all_outputs: Any, *args: Any): ...
    @staticmethod
    def backward(ctx: Any, *args: Any): ...



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

URL: str
MD5: str

class Imdb(Dataset):
    mode: Any = ...
    data_file: Any = ...
    word_idx: Any = ...
    def __init__(
        self, data_file: Optional[Any] = ..., mode: str = ..., cutoff: int = ..., download: bool = ...
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...



from __future__ import annotations

class Status:
    UNINIT: str = ...
    READY: str = ...
    RUNNING: str = ...
    FAILED: str = ...
    TERMINATING: str = ...
    RESTARTING: str = ...
    UNKNOWN: str = ...
    COMPLETED: str = ...
    DONE: str = ...
    def __init__(self) -> None: ...
    def current(self): ...
    def is_running(self): ...
    def is_restarting(self): ...
    def is_done(self): ...
    def run(self) -> None: ...
    def fail(self) -> None: ...
    def complete(self) -> None: ...
    def restart(self) -> None: ...
    def done(self) -> None: ...



from __future__ import annotations

from typing import Any

from ... import Tensor, nn

class VGG(nn.Layer):
    def __init__(
        self,
        features: nn.Layer,
        num_classes: int = ...,
        with_pool: bool = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    __call__ = forward

def make_layers(cfg: Any, batch_norm: bool = ...) -> nn.Layer: ...

cfgs: Any

def vgg11(
    pretrained: bool = ...,
    batch_norm: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> VGG: ...
def vgg13(
    pretrained: bool = ...,
    batch_norm: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> VGG: ...
def vgg16(
    pretrained: bool = ...,
    batch_norm: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> VGG: ...
def vgg19(
    pretrained: bool = ...,
    batch_norm: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> VGG: ...



from __future__ import annotations

from typing import Any

from ..utils import get_logger as get_logger

class Converter:
    def __init__(self, tensors_dict: Any, pre_strategy: Any, cur_strategy: Any) -> None: ...
    def convert(self, strict: bool = ...): ...
    def convert_with_prefix_match(self, tensors_dict: Any, tensor_not_in_pre: Any, tensor_not_in_cur: Any): ...
    @staticmethod
    def merge_and_slice(tensor_list: Any, pre_dist_attr: Any, cur_dist_attr: Any): ...
    @staticmethod
    def merge_with_dist_attr(tensor_list: Any, dist_attr: Any): ...
    @staticmethod
    def slice_with_dist_attr(tensor: Any, dist_attr: Any): ...
    @staticmethod
    def merge(partition_tensor_list: Any, tensor: Any, partition_index: Any, complete_shape: Any) -> None: ...
    @staticmethod
    def split(complete_tensor: Any, partition_index_list: Any, length: Any): ...



from __future__ import annotations

from typing import Any

logger: Any

def init_metric(
    metric_ptr: Any,
    metric_yaml_path: Any,
    cmatch_rank_var: str = ...,
    mask_var: str = ...,
    uid_var: str = ...,
    phase: int = ...,
    cmatch_rank_group: str = ...,
    ignore_rank: bool = ...,
    bucket_size: int = ...,
) -> None: ...
def print_metric(metric_ptr: Any, name: Any): ...
def print_auc(metric_ptr: Any, is_day: Any, phase: str = ...): ...



from __future__ import annotations

from typing import Any

def crepr(v: Any): ...

class Rank:
    kind: Any = ...
    name: Any = ...
    priority: Any = ...
    nodes: Any = ...
    def __init__(self, kind: Any, name: Any, priority: Any) -> None: ...

class Graph:
    rank_counter: int = ...
    title: Any = ...
    attrs: Any = ...
    nodes: Any = ...
    edges: Any = ...
    rank_groups: Any = ...
    def __init__(self, title: Any, **attrs: Any) -> None: ...
    def code(self): ...
    def rank_group(self, kind: Any, priority: Any): ...
    def node(self, label: Any, prefix: Any, description: str = ..., **attrs: Any): ...
    def edge(self, source: Any, target: Any, **attrs: Any): ...
    def compile(self, dot_path: Any): ...
    def show(self, dot_path: Any) -> None: ...

class Node:
    counter: int = ...
    label: Any = ...
    name: Any = ...
    description: Any = ...
    attrs: Any = ...
    def __init__(self, label: Any, prefix: Any, description: str = ..., **attrs: Any) -> None: ...

class Edge:
    source: Any = ...
    target: Any = ...
    attrs: Any = ...
    def __init__(self, source: Any, target: Any, **attrs: Any) -> None: ...

class GraphPreviewGenerator:
    graph: Any = ...
    op_rank: Any = ...
    param_rank: Any = ...
    arg_rank: Any = ...
    def __init__(self, title: Any) -> None: ...
    def __call__(self, path: str = ..., show: bool = ...) -> None: ...
    def add_param(self, name: Any, data_type: Any, highlight: bool = ...): ...
    def add_op(self, opType: Any, **kwargs: Any): ...
    def add_arg(self, name: Any, highlight: bool = ...): ...
    def add_edge(self, source: Any, target: Any, **kwargs: Any): ...



from __future__ import annotations

from copy import deepcopy as deepcopy
from typing import Any

from paddle.fluid import framework as framework

from .dist_attribute import OperatorDistributedAttribute as OperatorDistributedAttribute
from .dist_attribute import TensorDistributedAttribute as TensorDistributedAttribute
from .dist_context import (
    get_default_distributed_context as get_default_distributed_context,
)
from .dist_op import DistributedOperator as DistributedOperator
from .dist_tensor import DistributedTensor as DistributedTensor
from .operators import (
    find_best_compatible_distributed_operator_impl as find_best_compatible_distributed_operator_impl,
)
from .process_mesh import ProcessMesh as ProcessMesh
from .utils import print_program_with_dist_attr as print_program_with_dist_attr

def compute_compatible_process_mesh(process_mesh_list: Any): ...
def compute_compatible_dim_mapping(dim_mapping_list: Any): ...
def compute_compatible_dims_mapping(dims_mapping_list: Any): ...
def merge_process_mesh_two(pm1: Any, pm2: Any): ...

class Completer:
    def __init__(self, dist_context: Any) -> None: ...
    def complete_forward_annotation(self, serial_main_program: Any): ...
    def complete_backward_annotation(self, serial_main_program: Any): ...
    def complete_update_annotation(self, serial_main_program: Any) -> None: ...



from __future__ import annotations

from . import container as container
from . import rnn as rnn
from . import transformer as transformer
from .activation import CELU as CELU
from .activation import LeakyReLU as LeakyReLU
from .activation import LogSoftmax as LogSoftmax
from .activation import PReLU as PReLU
from .activation import ReLU as ReLU
from .activation import ReLU6 as ReLU6
from .activation import Sigmoid as Sigmoid
from .activation import Softmax as Softmax
from .common import AlphaDropout as AlphaDropout
from .common import Bilinear as Bilinear
from .common import CosineSimilarity as CosineSimilarity
from .common import Dropout as Dropout
from .common import Dropout2D as Dropout2D
from .common import Dropout3D as Dropout3D
from .common import Embedding as Embedding
from .common import Flatten as Flatten
from .common import Fold as Fold
from .common import Identity as Identity
from .common import Linear as Linear
from .common import Pad1D as Pad1D
from .common import Pad2D as Pad2D
from .common import Pad3D as Pad3D
from .common import Upsample as Upsample
from .common import UpsamplingBilinear2D as UpsamplingBilinear2D
from .common import UpsamplingNearest2D as UpsamplingNearest2D
from .common import ZeroPad2D as ZeroPad2D
from .container import LayerDict as LayerDict
from .conv import Conv1D as Conv1D
from .conv import Conv1DTranspose as Conv1DTranspose
from .conv import Conv2D as Conv2D
from .conv import Conv2DTranspose as Conv2DTranspose
from .conv import Conv3D as Conv3D
from .conv import Conv3DTranspose as Conv3DTranspose
from .distance import PairwiseDistance as PairwiseDistance
from .loss import BCELoss as BCELoss
from .loss import BCEWithLogitsLoss as BCEWithLogitsLoss
from .loss import CrossEntropyLoss as CrossEntropyLoss
from .loss import CTCLoss as CTCLoss
from .loss import HingeEmbeddingLoss as HingeEmbeddingLoss
from .loss import KLDivLoss as KLDivLoss
from .loss import L1Loss as L1Loss
from .loss import MarginRankingLoss as MarginRankingLoss
from .loss import MSELoss as MSELoss
from .loss import NLLLoss as NLLLoss
from .loss import SmoothL1Loss as SmoothL1Loss
from .norm import BatchNorm1D as BatchNorm1D
from .norm import BatchNorm2D as BatchNorm2D
from .norm import BatchNorm3D as BatchNorm3D
from .norm import GroupNorm as GroupNorm
from .norm import LayerNorm as LayerNorm
from .norm import LocalResponseNorm as LocalResponseNorm
from .norm import SpectralNorm as SpectralNorm
from .norm import SyncBatchNorm as SyncBatchNorm
from .pooling import AdaptiveAvgPool1D as AdaptiveAvgPool1D
from .pooling import AdaptiveAvgPool2D as AdaptiveAvgPool2D
from .pooling import AdaptiveAvgPool3D as AdaptiveAvgPool3D
from .pooling import AdaptiveMaxPool1D as AdaptiveMaxPool1D
from .pooling import AdaptiveMaxPool2D as AdaptiveMaxPool2D
from .pooling import AdaptiveMaxPool3D as AdaptiveMaxPool3D
from .pooling import AvgPool1D as AvgPool1D
from .pooling import AvgPool2D as AvgPool2D
from .pooling import AvgPool3D as AvgPool3D
from .pooling import MaxPool1D as MaxPool1D
from .pooling import MaxPool2D as MaxPool2D
from .pooling import MaxPool3D as MaxPool3D
from .pooling import MaxUnPool1D as MaxUnPool1D
from .pooling import MaxUnPool2D as MaxUnPool2D
from .pooling import MaxUnPool3D as MaxUnPool3D
from .vision import PixelShuffle as PixelShuffle



from __future__ import annotations

from distutils.command.build import build
from typing import Any, Optional

from setuptools.command.build_ext import build_ext
from setuptools.command.easy_install import easy_install

from ...fluid import core as core
from .extension_utils import CLANG_COMPILE_FLAGS as CLANG_COMPILE_FLAGS
from .extension_utils import CLANG_LINK_FLAGS as CLANG_LINK_FLAGS
from .extension_utils import IS_WINDOWS as IS_WINDOWS
from .extension_utils import MSVC_COMPILE_FLAGS as MSVC_COMPILE_FLAGS
from .extension_utils import OS_NAME as OS_NAME
from .extension_utils import CustomOpInfo as CustomOpInfo
from .extension_utils import add_compile_flag as add_compile_flag
from .extension_utils import add_std_without_repeat as add_std_without_repeat
from .extension_utils import bootstrap_context as bootstrap_context
from .extension_utils import check_abi_compatibility as check_abi_compatibility
from .extension_utils import (
    clean_object_if_change_cflags as clean_object_if_change_cflags,
)
from .extension_utils import find_cuda_home as find_cuda_home
from .extension_utils import find_rocm_home as find_rocm_home
from .extension_utils import get_build_directory as get_build_directory
from .extension_utils import is_cuda_file as is_cuda_file
from .extension_utils import log_v as log_v
from .extension_utils import normalize_extension_kwargs as normalize_extension_kwargs
from .extension_utils import parse_op_name_from as parse_op_name_from
from .extension_utils import prepare_unix_cudaflags as prepare_unix_cudaflags
from .extension_utils import prepare_win_cudaflags as prepare_win_cudaflags
from .extension_utils import run_cmd as run_cmd

CUDA_HOME: Any
ROCM_HOME: Any
CUDA_HOME = ROCM_HOME

def setup(**attr: Any) -> None: ...
def CppExtension(sources: Any, *args: Any, **kwargs: Any): ...
def CUDAExtension(sources: Any, *args: Any, **kwargs: Any): ...

class BuildExtension(build_ext):
    @classmethod
    def with_options(cls, **options: Any): ...
    no_python_abi_suffix: Any = ...
    output_dir: Any = ...
    contain_cuda_file: bool = ...
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def initialize_options(self) -> None: ...
    build_lib: Any = ...
    def finalize_options(self) -> None: ...
    cflags: Any = ...
    def build_extensions(self): ...
    def get_ext_filename(self, fullname: Any): ...

class EasyInstallCommand(easy_install):
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def run(self, *args: Any, **kwargs: Any) -> None: ...

class BuildCommand(build):
    @classmethod
    def with_options(cls, **options: Any): ...
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    build_base: Any = ...
    def initialize_options(self) -> None: ...

def load(
    name: Any,
    sources: Any,
    extra_cxx_cflags: Optional[Any] = ...,
    extra_cuda_cflags: Optional[Any] = ...,
    extra_ldflags: Optional[Any] = ...,
    extra_include_paths: Optional[Any] = ...,
    build_directory: Optional[Any] = ...,
    verbose: bool = ...,
): ...



from __future__ import annotations

from functools import reduce as reduce
from typing import Any, Optional

from paddle.fluid.distribute_lookup_table import (
    find_distributed_lookup_table as find_distributed_lookup_table,
)
from paddle.fluid.framework import Program as Program
from paddle.fluid.framework import default_startup_program as default_startup_program

from ..fluid import framework as framework
from ..fluid import layers as layers
from ..fluid import unique_name as unique_name
from ..fluid.backward import append_backward as append_backward
from ..fluid.clip import GradientClipBase as GradientClipBase
from ..fluid.clip import GradientClipByNorm as GradientClipByNorm
from ..fluid.dygraph import no_grad as no_grad
from ..fluid.framework import Parameter as Parameter
from ..fluid.framework import program_guard as program_guard
from ..fluid.initializer import Constant as Constant
from ..fluid.layer_helper import LayerHelper as LayerHelper
from ..fluid.layers import ops as ops
from ..fluid.wrapped_decorator import (
    signature_safe_contextmanager as signature_safe_contextmanager,
)
from .lr import LRScheduler as LRScheduler

class Optimizer:
    regularization: Any = ...
    helper: Any = ...
    clear_gradients: Any = ...
    def __init__(
        self,
        learning_rate: Any,
        parameters: Optional[Any] = ...,
        weight_decay: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ): ...
    def state_dict(self): ...
    def set_state_dict(self, state_dict: Any) -> None: ...
    def get_opti_var_name_list(self): ...
    def set_lr(self, value: Any) -> None: ...
    def get_lr(self): ...
    def backward(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameters: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        callbacks: Optional[Any] = ...,
    ): ...
    def apply_gradients(self, params_grads: Any): ...
    def append_regularization_ops(self, parameters_and_grads: Any, regularization: Optional[Any] = ...): ...
    def clear_grad(self, set_to_zero: bool = ...) -> None: ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameters: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...
    def step(self): ...



from __future__ import annotations

from collections import defaultdict as defaultdict
from typing import Any

from .graphviz import Graph as Graph

logger: Any
OP_STYLE: Any
VAR_STYLE: Any
GRAPH_STYLE: Any
GRAPH_ID: int

def unique_id(): ...
def draw_node(op: Any): ...
def draw_edge(var_parent: Any, op: Any, var: Any, arg: Any): ...
def parse_graph(program: Any, graph: Any, var_dict: Any, **kwargs: Any) -> None: ...
def draw_graph(startup_program: Any, main_program: Any, **kwargs: Any): ...



from __future__ import annotations

from test_imperative_qat import TestImperativeQat

class TestImperativeQatChannelWise(TestImperativeQat):
    weight_quantize_type: str = ...
    activation_quantize_type: str = ...
    diff_threshold: float = ...
    onnx_format: bool = ...
    fuse_conv_bn: bool = ...
    def set_vars(self) -> None: ...

class TestImperativeQatChannelWiseONNXFormat(TestImperativeQat):
    weight_quantize_type: str = ...
    activation_quantize_type: str = ...
    onnx_format: bool = ...
    diff_threshold: float = ...
    fuse_conv_bn: bool = ...
    def set_vars(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ...utils.log_util import logger as logger

class DygraphShardingOptimizer:
    def __init__(
        self,
        hcg: Any,
        user_defined_strategy: Any,
        params: Any,
        inner_optimizer_class: Any,
        **inner_optimizer_kargs: Any,
    ) -> None: ...
    def clear_grad(self) -> None: ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameters: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
    ): ...
    def step(self) -> None: ...
    def __getattr__(self, item: Any): ...



from __future__ import annotations

from contextlib import contextmanager as contextmanager
from threading import Thread as Thread
from typing import Any, Optional

from .checkpoint_saver import CheckpointSaver as CheckpointSaver
from .checkpoint_saver import PaddleModel as PaddleModel
from .checkpoint_saver import SerializableBase as SerializableBase

g_train_epoch_range: Any
g_checker: Any
logger: Any
generator: Any
CONST_CHECKPOINT: str
CONST_MEMORYINIT: str
CONST_DACP_TYPE: str
CONST_ACP_TYPE: str
g_acp_type: Any
g_program_attr: Any

class AutoCheckpointChecker:
    def __init__(self) -> None: ...
    def get_range_checkpoint_path(self, name: Any): ...
    def get_exe_checkpoint_path(self, name: Any): ...
    def get_job_path(self): ...
    @property
    def save_checkpoint_inter(self): ...
    def valid(self): ...
    @property
    def trainer_id(self): ...
    @property
    def run_env(self): ...
    @property
    def platform(self): ...
    @property
    def job_id(self): ...
    @property
    def hdfs_home(self): ...
    @property
    def hdfs_name(self): ...
    @property
    def ce_test(self): ...
    @property
    def hdfs_ugi(self): ...
    @property
    def hdfs_checkpoint_path(self): ...
    @staticmethod
    def generate_range_name(): ...

class ExeTrainStatus(SerializableBase):
    def __init__(self) -> None: ...
    def __eq__(self, t: Any) -> Any: ...
    def __ne__(self, t: Any) -> Any: ...
    def serialize(self, path: Any) -> None: ...
    def deserialize(self, path: Any) -> None: ...

class TrainEpochRange(SerializableBase):
    def __init__(
        self, max_epoch_num: Any, name: Any, checkpoint_inter: Optional[Any] = ..., restored: bool = ...
    ) -> None: ...
    @property
    def name(self): ...
    def serialize(self, path: Any) -> None: ...
    @property
    def restored_from(self): ...
    def deserialize(self, path: Any) -> None: ...
    def next(self) -> None: ...
    def get(self): ...
    def save_checkpoint(self) -> None: ...

def train_epoch_range(max_epoch_num: Any, save_checkpoint_inter: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def fc(
    x: Any,
    size: Any,
    num_flatten_dims: int = ...,
    weight_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    activation: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def deform_conv2d(
    x: Any,
    offset: Any,
    mask: Any,
    num_filters: Any,
    filter_size: Any,
    stride: int = ...,
    padding: int = ...,
    dilation: int = ...,
    groups: int = ...,
    deformable_groups: int = ...,
    im2col_step: int = ...,
    weight_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...



from __future__ import annotations

from collections import namedtuple as namedtuple
from typing import Any, Optional

class ProgressBar:
    file: Any = ...
    name: Any = ...
    def __init__(
        self,
        num: Optional[Any] = ...,
        width: int = ...,
        verbose: int = ...,
        start: bool = ...,
        file: Any = ...,
        name: str = ...,
    ) -> None: ...
    def start(self) -> None: ...
    def update(self, current_num: Any, values: Any = ...): ...



from __future__ import annotations

from typing import Any

from paddle.fluid import core as core
from paddle.fluid.data_feeder import check_dtype as check_dtype
from paddle.fluid.data_feeder import check_type as check_type
from paddle.fluid.framework import in_dygraph_mode as in_dygraph_mode
from paddle.fluid.layers import control_flow as control_flow
from paddle.fluid.layers import elementwise_add as elementwise_add
from paddle.fluid.layers import elementwise_div as elementwise_div
from paddle.fluid.layers import elementwise_mul as elementwise_mul
from paddle.fluid.layers import elementwise_sub as elementwise_sub
from paddle.fluid.layers import nn as nn
from paddle.fluid.layers import ops as ops
from paddle.tensor import arange as arange
from paddle.tensor import concat as concat
from paddle.tensor import gather_nd as gather_nd
from paddle.tensor import multinomial as multinomial

class Distribution:
    def __init__(self, batch_shape: Any = ..., event_shape: Any = ...) -> None: ...
    @property
    def batch_shape(self): ...
    @property
    def event_shape(self): ...
    @property
    def mean(self) -> None: ...
    @property
    def variance(self) -> None: ...
    def sample(self, shape: Any = ...) -> None: ...
    def rsample(self, shape: Any = ...) -> None: ...
    def entropy(self) -> None: ...
    def kl_divergence(self, other: Any) -> None: ...
    def prob(self, value: Any): ...
    def log_prob(self, value: Any) -> None: ...
    def probs(self, value: Any) -> None: ...



from __future__ import annotations

from typing import Optional

from paddle import ParamAttr
from paddle.incubate.nn import functional as F
from paddle.nn import Layer

class FusedLinear(Layer):
    def __init__(
        self,
        in_features: int,
        out_features: int,
        weight_attr: ParamAttr = ...,
        bias_attr: ParamAttr = ...,
        transpose_weight: bool = ...,
        name: Optional[str] = ...,
    ): ...
    def forward(self, input): ...
    __call__ = forward



from __future__ import annotations

from typing import Any, Optional

class LayerHelperBase:
    def __init__(self, name: Any, layer_type: Any) -> None: ...
    @property
    def name(self): ...
    @property
    def layer_type(self): ...
    @property
    def main_program(self): ...
    @property
    def startup_program(self): ...
    @classmethod
    def set_default_dtype(cls, dtype: Any) -> None: ...
    @classmethod
    def get_default_dtype(cls): ...
    def to_variable(self, value: Any, name: Optional[Any] = ...): ...
    def create_parameter(
        self,
        attr: Any,
        shape: Any,
        dtype: Optional[Any] = ...,
        is_bias: bool = ...,
        default_initializer: Optional[Any] = ...,
        stop_gradient: bool = ...,
        type: Any = ...,
    ): ...
    def create_variable_for_type_inference(self, dtype: Any, stop_gradient: bool = ..., shape: Optional[Any] = ...): ...
    def create_variable(self, *args: Any, **kwargs: Any): ...
    def create_global_variable(self, persistable: bool = ..., *args: Any, **kwargs: Any): ...
    def create_or_get_global_variable(self, name: Any, *args: Any, **kwargs: Any): ...
    def set_variable_initializer(self, var: Any, initializer: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

URL_DEV_TEST: str
MD5_DEV_TEST: str
URL_TRAIN: str
MD5_TRAIN: str
START: str
END: str
UNK: str
UNK_IDX: int

class WMT14(Dataset):
    mode: Any = ...
    data_file: Any = ...
    dict_size: Any = ...
    def __init__(
        self, data_file: Optional[Any] = ..., mode: str = ..., dict_size: int = ..., download: bool = ...
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...
    def get_dict(self, reverse: bool = ...): ...



from __future__ import annotations

from collections import namedtuple
from typing import Any, Optional

from ...fluid import core as core
from ...fluid.framework import OpProtoHolder as OpProtoHolder
from ...sysconfig import get_include as get_include
from ...sysconfig import get_lib as get_lib

logger: Any
formatter: Any
ch: Any
OS_NAME: Any
IS_WINDOWS: Any
MSVC_COMPILE_FLAGS: Any
CLANG_COMPILE_FLAGS: Any
CLANG_LINK_FLAGS: Any
MSVC_LINK_FLAGS: Any
COMMON_HIPCC_FLAGS: Any
COMMON_NVCC_FLAGS: Any
GCC_MINI_VERSION: Any
MSVC_MINI_VERSION: Any
WRONG_COMPILER_WARNING: str
ABI_INCOMPATIBILITY_WARNING: str
DEFAULT_OP_ATTR_NAMES: Any

def bootstrap_context() -> None: ...
def load_op_meta_info_and_register_op(lib_filename: Any): ...
def custom_write_stub(resource: Any, pyfile: Any) -> None: ...

OpInfo = namedtuple("OpInfo", ["so_name", "so_path"])

class CustomOpInfo:
    @classmethod
    def instance(cls): ...
    op_info_map: Any = ...
    def __init__(self) -> None: ...
    def add(self, op_name: Any, so_name: Any, so_path: Optional[Any] = ...) -> None: ...
    def last(self): ...

VersionFields = namedtuple(
    "VersionFields",
    [
        "sources",
        "extra_compile_args",
        "extra_link_args",
        "library_dirs",
        "runtime_library_dirs",
        "include_dirs",
        "define_macros",
        "undef_macros",
    ],
)

class VersionManager:
    version_field: Any = ...
    version: Any = ...
    def __init__(self, version_field: Any) -> None: ...
    def hasher(self, version_field: Any): ...
    @property
    def details(self): ...

def combine_hash(md5: Any, value: Any): ...
def clean_object_if_change_cflags(so_path: Any, extension: Any): ...
def prepare_unix_cudaflags(cflags: Any): ...
def prepare_win_cudaflags(cflags: Any): ...
def add_std_without_repeat(cflags: Any, compiler_type: Any, use_std14: bool = ...) -> None: ...
def get_cuda_arch_flags(cflags: Any): ...
def get_rocm_arch_flags(cflags: Any): ...
def normalize_extension_kwargs(kwargs: Any, use_cuda: bool = ...): ...
def create_sym_link_if_not_exist(): ...
def find_cuda_home(): ...
def find_rocm_home(): ...
def find_cuda_includes(): ...
def find_rocm_includes(): ...
def find_paddle_includes(use_cuda: bool = ...): ...
def find_clang_cpp_include(compiler: str = ...): ...
def find_cuda_libraries(): ...
def find_rocm_libraries(): ...
def find_paddle_libraries(use_cuda: bool = ...): ...
def add_compile_flag(extra_compile_args: Any, flags: Any) -> None: ...
def is_cuda_file(path: Any): ...
def get_build_directory(verbose: bool = ...): ...
def parse_op_info(op_name: Any): ...
def list2str(args: Any): ...
def parse_op_name_from(sources: Any): ...
def run_cmd(command: Any, verbose: bool = ...): ...
def check_abi_compatibility(compiler: Any, verbose: bool = ...): ...
def log_v(info: Any, verbose: bool = ...) -> None: ...



from __future__ import annotations

import abc
from typing import Any

from ..dist_attribute import (
    OperatorDistributedAttribute as OperatorDistributedAttribute,
)

BACKWARD_ONLY_DIST_OPS: Any

def is_elementwise_op(op_type: Any): ...

class DistributedOperatorImplContainer:
    def __init__(self, op_type: Any) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, op_type: Any) -> None: ...
    @property
    def impls(self): ...
    def register_impl(self, dist_impl: Any) -> None: ...
    def get_impl(self, impl_idx: Any): ...
    def get_input_compatible_impls(self, dist_op: Any): ...
    def get_output_compatible_impls(self, dist_op: Any): ...
    def get_compatible_impls(self, dist_op: Any): ...

class DistributedOperatorImpl(abc.ABC, metaclass=abc.ABCMeta):
    def __init__(self, name: Any) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name: Any) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, op_type: Any) -> None: ...
    @property
    def idx(self): ...
    @idx.setter
    def idx(self, impl_idx: Any) -> None: ...
    @abc.abstractmethod
    def is_input_compatible(self, dist_op: Any) -> Any: ...
    @abc.abstractmethod
    def is_output_compatible(self, dist_op: Any) -> Any: ...
    @abc.abstractmethod
    def is_auto_compatible(self, dist_op: Any) -> Any: ...
    @staticmethod
    @abc.abstractmethod
    def forward(dist_ctx: Any, *args: Any, **kwargs: Any) -> Any: ...
    @staticmethod
    @abc.abstractmethod
    def backward(dist_ctx: Any, *grad_outputs: Any, **kwargs: Any) -> Any: ...
    def update_dims_mapping(self, dist_op: Any) -> None: ...

def register_distributed_operator_impl_container(container: Any) -> None: ...
def get_distributed_operator_impl_container(op_type: Any): ...
def register_distributed_operator_impl(op_type: Any, dist_impl: Any) -> None: ...
def find_best_compatible_distributed_operator_impl(dist_op: Any, fwd: bool = ...): ...
def is_parameter_related(varname: Any, block: Any): ...
def infer_shape(block: Any, src_var: Any, src_var_dist_attr: Any, op_input_dist_attr: Any): ...
def set_comm_op_dist_attr_for_program(new_op: Any, process_mesh: Any, tensor_dist_attr: Any, ctx: Any) -> None: ...
def naive_copy_op_dist_attr_for_program(new_op: Any, ref_op: Any, ctx: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def memory_optimize(
    input_program: Any,
    skip_opt_set: Optional[Any] = ...,
    print_log: bool = ...,
    level: int = ...,
    skip_grads: bool = ...,
) -> None: ...
def release_memory(input_program: Any, skip_opt_set: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from ...fluid.initializer import NormalInitializer as NormalInitializer
from ...fluid.initializer import (
    TruncatedNormalInitializer as TruncatedNormalInitializer,
)

class Normal(NormalInitializer):
    def __init__(self, mean: float = ..., std: float = ..., name: Optional[Any] = ...) -> None: ...

class TruncatedNormal(TruncatedNormalInitializer):
    def __init__(self, mean: float = ..., std: float = ..., name: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from .dist_attribute import TensorDistributedAttribute as TensorDistributedAttribute
from .dist_attribute import (
    get_tensor_dist_attr_field_keys as get_tensor_dist_attr_field_keys,
)

class DistributedTensor:
    @staticmethod
    def get_local_sizes(
        global_sizes: Any,
        dims_mapping: Any,
        topology: Any,
        processes: Any,
        rank: Optional[Any] = ...,
        shard_sizes: Optional[Any] = ...,
    ): ...
    @staticmethod
    def get_local_offsets(
        global_sizes: Any, dims_mapping: Any, topology: Any, processes: Any, rank: Any, shard_sizes: Optional[Any] = ...
    ): ...
    @staticmethod
    def get_global_sizes(
        local_sizes: Any,
        dims_mapping: Any,
        topology: Any,
        processes: Any,
        rank: Optional[Any] = ...,
        shard_sizes: Optional[Any] = ...,
    ): ...
    @staticmethod
    def get_local_shard(
        global_sizes: Any, dims_mapping: Any, topology: Any, processes: Any, rank: Any, shard_sizes: Optional[Any] = ...
    ): ...
    def __init__(
        self, serial_tensor: Any, dist_attr: Optional[Any] = ..., dist_context: Optional[Any] = ...
    ) -> None: ...
    @property
    def serial_tensor(self): ...
    @property
    def dist_attr(self): ...
    @property
    def dist_context(self): ...
    @dist_attr.setter
    def dist_attr(self, dist_attr: Any) -> None: ...
    def validate_dist_attr(self): ...
    def local_sizes(self, rank: Optional[Any] = ...): ...
    def local_offsets(self, rank: Optional[Any] = ...): ...
    def global_sizes(self): ...
    def local_shard(self, rank: Optional[Any] = ...): ...
    def new_local_tensor(self, block: Optional[Any] = ..., rank: Optional[Any] = ..., name: Optional[Any] = ...): ...
    def local_tensor(self, rank: Optional[Any] = ...): ...
    def __deepcopy__(self, memo: Any): ...



from __future__ import annotations

from typing import Any, Optional

class LayerOpsRecoder:
    start: Any = ...
    end: Any = ...
    ops: Any = ...
    is_valid: Any = ...
    hooks: Any = ...
    def __init__(
        self,
        start: int = ...,
        end: int = ...,
        ops: Optional[Any] = ...,
        is_valid: bool = ...,
        hooks: Optional[Any] = ...,
    ) -> None: ...

def record_program_ops_pre_hook(layer: Any, inputs: Any) -> None: ...
def set_op_customized_attrs_post_hook(layer: Any, inputs: Any, outputs: Any) -> None: ...



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['paddle-stubs']

package_data = \
{'': ['*'],
 'paddle-stubs': ['amp/*',
                  'autograd/*',
                  'cost_model/*',
                  'dataset/*',
                  'device/*',
                  'device/cuda/*',
                  'distributed/*',
                  'distributed/auto_parallel/*',
                  'distributed/auto_parallel/cost/*',
                  'distributed/auto_parallel/operators/*',
                  'distributed/auto_parallel/tuner/*',
                  'distributed/fleet/*',
                  'distributed/fleet/base/*',
                  'distributed/fleet/data_generator/*',
                  'distributed/fleet/dataset/*',
                  'distributed/fleet/elastic/*',
                  'distributed/fleet/meta_optimizers/*',
                  'distributed/fleet/meta_optimizers/ascend/*',
                  'distributed/fleet/meta_optimizers/dygraph_optimizer/*',
                  'distributed/fleet/meta_optimizers/sharding/*',
                  'distributed/fleet/meta_parallel/*',
                  'distributed/fleet/meta_parallel/parallel_layers/*',
                  'distributed/fleet/meta_parallel/pp_utils/*',
                  'distributed/fleet/meta_parallel/sharding/*',
                  'distributed/fleet/metrics/*',
                  'distributed/fleet/runtime/*',
                  'distributed/fleet/utils/*',
                  'distributed/launch/*',
                  'distributed/launch/context/*',
                  'distributed/launch/controllers/*',
                  'distributed/launch/job/*',
                  'distributed/launch/plugins/*',
                  'distributed/launch/utils/*',
                  'distributed/metric/*',
                  'distributed/models/*',
                  'distributed/models/moe/*',
                  'distributed/passes/*',
                  'distributed/ps/*',
                  'distributed/ps/utils/*',
                  'distributed/sharding/*',
                  'distribution/*',
                  'fluid/*',
                  'fluid/contrib/*',
                  'fluid/contrib/decoder/*',
                  'fluid/contrib/extend_optimizer/*',
                  'fluid/contrib/layers/*',
                  'fluid/contrib/mixed_precision/*',
                  'fluid/contrib/mixed_precision/bf16/*',
                  'fluid/contrib/quantize/*',
                  'fluid/contrib/slim/*',
                  'fluid/contrib/slim/quantization/*',
                  'fluid/contrib/slim/quantization/imperative/*',
                  'fluid/contrib/slim/tests/*',
                  'fluid/contrib/sparsity/*',
                  'fluid/dataloader/*',
                  'fluid/distributed/*',
                  'fluid/dygraph/*',
                  'fluid/dygraph/amp/*',
                  'fluid/dygraph/dygraph_to_static/*',
                  'fluid/incubate/*',
                  'fluid/incubate/checkpoint/*',
                  'fluid/incubate/data_generator/*',
                  'fluid/incubate/fleet/*',
                  'fluid/incubate/fleet/base/*',
                  'fluid/incubate/fleet/collective/*',
                  'fluid/incubate/fleet/parameter_server/*',
                  'fluid/incubate/fleet/parameter_server/distribute_transpiler/*',
                  'fluid/incubate/fleet/parameter_server/ir/*',
                  'fluid/incubate/fleet/parameter_server/pslib/*',
                  'fluid/incubate/fleet/utils/*',
                  'fluid/inference/*',
                  'fluid/layers/*',
                  'fluid/transpiler/*',
                  'fluid/transpiler/details/*',
                  'framework/*',
                  'hapi/*',
                  'incubate/*',
                  'incubate/autograd/*',
                  'incubate/checkpoint/*',
                  'incubate/multiprocessing/*',
                  'incubate/nn/*',
                  'incubate/nn/functional/*',
                  'incubate/nn/layer/*',
                  'incubate/operators/*',
                  'incubate/optimizer/*',
                  'incubate/optimizer/functional/*',
                  'incubate/passes/*',
                  'incubate/tensor/*',
                  'io/*',
                  'jit/*',
                  'jit/dy2static/*',
                  'libs/*',
                  'metric/*',
                  'nn/*',
                  'nn/functional/*',
                  'nn/initializer/*',
                  'nn/layer/*',
                  'nn/quant/*',
                  'nn/utils/*',
                  'onnx/*',
                  'optimizer/*',
                  'profiler/*',
                  'reader/*',
                  'reader/tests/*',
                  'sparse/*',
                  'sparse/functional/*',
                  'sparse/layer/*',
                  'static/*',
                  'static/amp/*',
                  'static/nn/*',
                  'static/sparsity/*',
                  'tensor/*',
                  'text/*',
                  'text/datasets/*',
                  'utils/*',
                  'utils/cpp_extension/*',
                  'utils/gast/*',
                  'vision/*',
                  'vision/datasets/*',
                  'vision/models/*',
                  'vision/transforms/*']}

install_requires = \
['paddlepaddle>=2.3.1,<3.0.0', 'typing-extensions>=4.3.0,<5.0.0']

setup_kwargs = {
    'name': 'paddlepaddle-stubs',
    'version': '2.3.1.dev0',
    'description': '',
    'long_description': 'None',
    'author': 'Nyakku Shigure',
    'author_email': 'sigure.qaq@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from __future__ import annotations

from typing import Any, Optional

class CUDAGraph:
    def __init__(self, place: Optional[Any] = ..., mode: str = ...) -> None: ...
    def capture_begin(self) -> None: ...
    def capture_end(self) -> None: ...
    def replay(self) -> None: ...
    def reset(self) -> None: ...
    def print_to_dot_files(self, dirname: Any, flags: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any, Optional

class TunableVariable:
    name: Any = ...
    def __init__(self, name: Any, default: Optional[Any] = ...) -> None: ...
    @property
    def default(self): ...
    def get_state(self): ...
    @classmethod
    def from_state(cls, state: Any): ...

class Fixed(TunableVariable):
    name: Any = ...
    def __init__(self, name: Any, default: Any) -> None: ...
    def random(self, seed: Optional[Any] = ...): ...

class Boolean(TunableVariable):
    def __init__(self, name: Any, default: bool = ...) -> None: ...
    def random(self, seed: Optional[Any] = ...): ...

class Choice(TunableVariable):
    values: Any = ...
    def __init__(self, name: Any, values: Any, default: Optional[Any] = ...) -> None: ...
    @property
    def default(self): ...
    def random(self, seed: Optional[Any] = ...): ...
    def get_state(self): ...

class IntRange(TunableVariable):
    start: Any = ...
    stop: Any = ...
    step: Any = ...
    endpoint: Any = ...
    def __init__(
        self, name: Any, start: Any, stop: Any, step: int = ..., default: Optional[Any] = ..., endpoint: bool = ...
    ) -> None: ...
    @property
    def default(self): ...
    def random(self, seed: Optional[Any] = ...): ...
    def get_state(self): ...

class FloatRange(TunableVariable):
    stop: Any = ...
    start: Any = ...
    step: Any = ...
    endpoint: Any = ...
    def __init__(
        self,
        name: Any,
        start: Any,
        stop: Any,
        step: Optional[Any] = ...,
        default: Optional[Any] = ...,
        endpoint: bool = ...,
    ) -> None: ...
    @property
    def default(self): ...
    def random(self, seed: Optional[Any] = ...): ...
    def get_state(self): ...



from __future__ import annotations

from . import dist_check_finite_and_unscale as dist_check_finite_and_unscale
from . import dist_default as dist_default
from . import dist_eltwise as dist_eltwise
from . import dist_embedding as dist_embedding
from . import dist_fill_constant_batch_size_like as dist_fill_constant_batch_size_like
from . import dist_matmul as dist_matmul
from . import dist_reshape as dist_reshape
from . import dist_softmax as dist_softmax
from . import dist_split as dist_split
from . import dist_transpose as dist_transpose
from . import dist_update_loss_scaling as dist_update_loss_scaling
from .common import DistributedOperatorImpl as DistributedOperatorImpl
from .common import DistributedOperatorImplContainer as DistributedOperatorImplContainer
from .common import (
    find_best_compatible_distributed_operator_impl as find_best_compatible_distributed_operator_impl,
)
from .common import (
    register_distributed_operator_impl as register_distributed_operator_impl,
)
from .common import (
    register_distributed_operator_impl_container as register_distributed_operator_impl_container,
)



from __future__ import annotations

from collections import OrderedDict as OrderedDict
from typing import Any

from .pass_base import PassBase as PassBase
from .pass_base import register_pass as register_pass

OpRole: Any
OP_ROLE_KEY: Any

class ShardingPass(PassBase):
    dp_groups: Any = ...
    sharding_infos: Any = ...
    varname_to_sharding_info: Any = ...
    partial_sharding: bool = ...
    outer_dp_group: Any = ...
    def __init__(self) -> None: ...

def shard_parameters(params: Any, group_size: Any): ...

class ShardingInfo:
    group: Any = ...
    params: Any = ...
    param_names: Any = ...
    group_size: Any = ...
    global_rank: Any = ...
    local_rank: Any = ...
    rank_to_params: Any = ...
    param_to_rank: Any = ...
    def __init__(self, group: Any, rank: Any, params: Any) -> None: ...
    def get_var_rank(self, varname: Any): ...
    def is_in_local_shard(self, param_name: Any): ...
    def get_broadcast_vars_and_param_usage(self, block: Any): ...



from __future__ import annotations

from .metric import acc as acc
from .metric import auc as auc
from .metric import mae as mae
from .metric import max as max
from .metric import min as min
from .metric import mse as mse
from .metric import rmse as rmse
from .metric import sum as sum



from __future__ import annotations

import unittest
from typing import Any, Optional

def conv_net(img: Any, label: Any): ...
def pact(x: Any, name: Optional[Any] = ...): ...

class TestUserDefinedQuantization(unittest.TestCase):
    def quantization_scale(
        self,
        use_cuda: Any,
        seed: Any,
        activation_quant_type: Any,
        weight_quant_type: str = ...,
        for_ci: bool = ...,
        act_preprocess_func: Optional[Any] = ...,
        weight_preprocess_func: Optional[Any] = ...,
        act_quantize_func: Optional[Any] = ...,
        weight_quantize_func: Optional[Any] = ...,
    ): ...
    def test_act_preprocess_cuda(self) -> None: ...
    def test_act_preprocess_cpu(self) -> None: ...
    def test_weight_preprocess_cuda(self) -> None: ...
    def test_weight_preprocess_cpu(self) -> None: ...
    def test_act_quantize_cuda(self) -> None: ...
    def test_act_quantize_cpu(self) -> None: ...
    def test_weight_quantize_cuda(self) -> None: ...
    def test_weight_quantize_cpu(self) -> None: ...



from __future__ import annotations

from typing import Any

from ... import Tensor, nn
from ..ops import ConvNormActivation as ConvNormActivation

class InceptionStem(nn.Layer):
    conv_1a_3x3: Any = ...
    conv_2a_3x3: Any = ...
    conv_2b_3x3: Any = ...
    max_pool: Any = ...
    conv_3b_1x1: Any = ...
    conv_4a_3x3: Any = ...
    def __init__(self) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class InceptionA(nn.Layer):
    branch1x1: Any = ...
    branch5x5_1: Any = ...
    branch5x5_2: Any = ...
    branch3x3dbl_1: Any = ...
    branch3x3dbl_2: Any = ...
    branch3x3dbl_3: Any = ...
    branch_pool: Any = ...
    branch_pool_conv: Any = ...
    def __init__(self, num_channels: Any, pool_features: Any) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class InceptionB(nn.Layer):
    branch3x3: Any = ...
    branch3x3dbl_1: Any = ...
    branch3x3dbl_2: Any = ...
    branch3x3dbl_3: Any = ...
    branch_pool: Any = ...
    def __init__(self, num_channels: Any) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class InceptionC(nn.Layer):
    branch1x1: Any = ...
    branch7x7_1: Any = ...
    branch7x7_2: Any = ...
    branch7x7_3: Any = ...
    branch7x7dbl_1: Any = ...
    branch7x7dbl_2: Any = ...
    branch7x7dbl_3: Any = ...
    branch7x7dbl_4: Any = ...
    branch7x7dbl_5: Any = ...
    branch_pool: Any = ...
    branch_pool_conv: Any = ...
    def __init__(self, num_channels: Any, channels_7x7: Any) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class InceptionD(nn.Layer):
    branch3x3_1: Any = ...
    branch3x3_2: Any = ...
    branch7x7x3_1: Any = ...
    branch7x7x3_2: Any = ...
    branch7x7x3_3: Any = ...
    branch7x7x3_4: Any = ...
    branch_pool: Any = ...
    def __init__(self, num_channels: Any) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class InceptionE(nn.Layer):
    branch1x1: Any = ...
    branch3x3_1: Any = ...
    branch3x3_2a: Any = ...
    branch3x3_2b: Any = ...
    branch3x3dbl_1: Any = ...
    branch3x3dbl_2: Any = ...
    branch3x3dbl_3a: Any = ...
    branch3x3dbl_3b: Any = ...
    branch_pool: Any = ...
    branch_pool_conv: Any = ...
    def __init__(self, num_channels: Any) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class InceptionV3(nn.Layer):
    num_classes: Any = ...
    with_pool: Any = ...
    layers_config: Any = ...
    inception_stem: Any = ...
    inception_block_list: Any = ...
    avg_pool: Any = ...
    dropout: Any = ...
    fc: Any = ...
    def __init__(
        self,
        num_classes: int = ...,
        with_pool: bool = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    __call__ = forward

def inception_v3(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
) -> InceptionV3: ...



from __future__ import annotations

from typing import Any, Optional

def global_scatter(
    x: Any, local_count: Any, global_count: Any, group: Optional[Any] = ..., use_calc_stream: bool = ...
): ...
def global_gather(
    x: Any, local_count: Any, global_count: Any, group: Optional[Any] = ..., use_calc_stream: bool = ...
): ...

class Hdfs:
    hdfs_ugi: Any = ...
    hdfs_name: Any = ...
    hdfs_path: Any = ...
    def __init__(self) -> None: ...
    def is_valid(self): ...
    def __eq__(self, n: Any) -> Any: ...
    def __ne__(self, n: Any) -> Any: ...

class Cluster:
    job_server: Any = ...
    pods: Any = ...
    hdfs: Any = ...
    job_stage_flag: Any = ...
    def __init__(self, hdfs: Any) -> None: ...
    def __eq__(self, cluster: Any) -> Any: ...
    def __ne__(self, cluster: Any) -> Any: ...
    def update_pods(self, cluster: Any) -> None: ...
    def trainers_nranks(self): ...
    def pods_nranks(self): ...
    def trainers_endpoints(self): ...
    def pods_endpoints(self): ...
    def get_pod_by_id(self, pod_id: Any): ...

class JobServer:
    endpoint: Any = ...
    def __init__(self) -> None: ...
    def __eq__(self, j: Any) -> Any: ...
    def __ne__(self, j: Any) -> Any: ...

class Trainer:
    gpus: Any = ...
    endpoint: Any = ...
    rank: Any = ...
    def __init__(self) -> None: ...
    def __eq__(self, t: Any) -> Any: ...
    def __ne__(self, t: Any) -> Any: ...
    def get_rank(self): ...

class Pod:
    rank: Any = ...
    id: Any = ...
    addr: Any = ...
    port: Any = ...
    trainers: Any = ...
    gpus: Any = ...
    def __init__(self) -> None: ...
    def __eq__(self, pod: Any) -> Any: ...
    def __ne__(self, pod: Any) -> Any: ...
    def parse_response(self, res_pods: Any) -> None: ...
    def get_visible_gpus(self): ...

def get_logger(log_level: Any, name: str = ...): ...
def get_cluster(node_ips: Any, node_ip: Any, trainer_endpoints: Any, selected_gpus: Any): ...
def terminate_local_procs(procs: Any) -> None: ...
def get_host_name_ip(): ...
def add_arguments(argname: Any, type: Any, default: Any, help: Any, argparser: Any, **kwargs: Any) -> None: ...
def find_free_ports(num: Any): ...

class TrainerProc:
    proc: Any = ...
    log_fn: Any = ...
    log_offset: Any = ...
    rank: Any = ...
    local_rank: Any = ...
    cmd: Any = ...
    def __init__(self) -> None: ...

def start_local_trainers(
    cluster: Any, pod: Any, training_script: Any, training_script_args: Any, log_dir: Optional[Any] = ...
): ...
def pull_worker_log(tp: Any) -> None: ...
def watch_local_trainers(procs: Any, nranks: Any): ...



from __future__ import annotations

from typing import Any

from paddle.fluid.incubate.fleet.parameter_server.ir.trainer_pass import (
    find_op_input_output as find_op_input_output,
)
from paddle.fluid.incubate.fleet.parameter_server.ir.trainer_pass import (
    get_vars_name_in_block as get_vars_name_in_block,
)
from paddle.fluid.transpiler.details.program_utils import delete_ops as delete_ops

def split_heter_worker_ops_pass(program: Any, config: Any, stage_id: Any, device: Any): ...
def split_trainer_ops_pass(program: Any, config: Any, default_device: str = ...): ...



from __future__ import annotations

from typing import Any, Optional

from ... import Tensor, nn

class BasicBlock(nn.Layer):
    expansion: int = ...
    conv1: Any = ...
    bn1: Any = ...
    relu: Any = ...
    conv2: Any = ...
    bn2: Any = ...
    downsample: Any = ...
    stride: Any = ...
    def __init__(
        self,
        inplanes: Any,
        planes: Any,
        stride: int = ...,
        downsample: Optional[Any] = ...,
        groups: int = ...,
        base_width: int = ...,
        dilation: int = ...,
        norm_layer: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class BottleneckBlock(nn.Layer):
    expansion: int = ...
    conv1: Any = ...
    bn1: Any = ...
    conv2: Any = ...
    bn2: Any = ...
    conv3: Any = ...
    bn3: Any = ...
    relu: Any = ...
    downsample: Any = ...
    stride: Any = ...
    def __init__(
        self,
        inplanes: Any,
        planes: Any,
        stride: int = ...,
        downsample: Optional[Any] = ...,
        groups: int = ...,
        base_width: int = ...,
        dilation: int = ...,
        norm_layer: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any) -> Tensor: ...

class ResNet(nn.Layer):
    def __init__(
        self,
        block: type[BasicBlock] | type[BottleneckBlock],
        depth: int = ...,
        width: int = ...,
        num_classes: int = ...,
        with_pool: bool = ...,
        groups: int = ...,
    ) -> None: ...
    def forward(self, x: Tensor) -> Tensor: ...
    __call__ = forward

def resnet18(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnet34(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnet50(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnet101(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnet152(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnext50_32x4d(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnext50_64x4d(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnext101_32x4d(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnext101_64x4d(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnext152_32x4d(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def resnext152_64x4d(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def wide_resnet50_2(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...
def wide_resnet101_2(
    pretrained: bool = ...,
    *,
    num_classes: int = ...,
    with_pool: bool = ...,
    groups: int = ...,
) -> ResNet: ...



from __future__ import annotations

from typing import Any

DESCRIPTOR: Any
TableType: Any
PsCmdID: Any
PS_SPARSE_TABLE: int
PS_DENSE_TABLE: int
PS_PULL_DENSE_TABLE: int
PS_PUSH_DENSE_TABLE: int
PS_PULL_SPARSE_TABLE: int
PS_PUSH_SPARSE_TABLE: int
PS_SHRINK_TABLE: int
PS_SAVE_ONE_TABLE: int
PS_SAVE_ALL_TABLE: int
PS_LOAD_ONE_TABLE: int
PS_LOAD_ALL_TABLE: int
PS_CLEAR_ONE_TABLE: int
PS_CLEAR_ALL_TABLE: int
PS_PUSH_DENSE_PARAM: int
PS_STOP_SERVER: int
PS_SAVE_ONE_CACHE_TABLE: int
PS_GET_CACHE_THRESHOLD: int
PS_CACHE_SHUFFLE: int
PS_COPY_TABLE: int
PS_COPY_TABLE_BY_FEASIGN: int
PS_PULL_SPARSE_TABLE_WITH_DEPENDENCY: int
PS_PUSH_SPARSE_TABLE_WITH_DEPENDENCY: int
PS_PRINT_TABLE_STAT: int
PS_S2S_MSG: int
PSParameter: Any
WorkerParameter: Any
ServerParameter: Any
DownpourWorkerParameter: Any
DownpourTrainerParameter: Any
ProgramConfig: Any
DenseTableParameter: Any
SparseTableParameter: Any
DownpourServerParameter: Any
ServerServiceParameter: Any
TableParameter: Any
TableAccessorParameter: Any
DownpourTableAccessorParameter: Any
TableAccessorSaveParameter: Any
PsRequestMessage: Any
SparseSGDRuleParameter: Any
SparseCommonSGDRuleParameter: Any
SparseNaiveSGDRuleParameter: Any
SparseAdagradSGDRuleParameter: Any
SparseAdamSGDParameter: Any
DenseSGDRuleParameter: Any
AdamSGDParameter: Any
NaiveSGDParameter: Any
SummarySGDParameter: Any
MovingAverageRuleParameter: Any
PsResponseMessage: Any
FsClientParameter: Any



from __future__ import annotations

from typing import Any, Optional

from paddle.io import Dataset

DATA_URL: str
DATA_MD5: str
WORDDICT_URL: str
WORDDICT_MD5: str
VERBDICT_URL: str
VERBDICT_MD5: str
TRGDICT_URL: str
TRGDICT_MD5: str
EMB_URL: str
EMB_MD5: str
UNK_IDX: int

class Conll05st(Dataset):
    data_file: Any = ...
    word_dict_file: Any = ...
    verb_dict_file: Any = ...
    target_dict_file: Any = ...
    emb_file: Any = ...
    word_dict: Any = ...
    predicate_dict: Any = ...
    label_dict: Any = ...
    def __init__(
        self,
        data_file: Optional[Any] = ...,
        word_dict_file: Optional[Any] = ...,
        verb_dict_file: Optional[Any] = ...,
        target_dict_file: Optional[Any] = ...,
        emb_file: Optional[Any] = ...,
        download: bool = ...,
    ) -> None: ...
    def __getitem__(self, idx: Any): ...
    def __len__(self): ...
    def get_dict(self): ...
    def get_embedding(self): ...



from __future__ import annotations

from typing import Any, Optional

class NestSequence:
    def __init__(self, raw_input: Any, need_check: bool = ...) -> None: ...
    def tolist(self): ...
    def restore(self, value_list: Any): ...
    @property
    def var_ids(self): ...
    def __getitem__(self, item: Any): ...

class LazyInitialized:
    function: Any = ...
    def __init__(self, function: Any) -> None: ...
    def __get__(self, instance: Any, cls: Any): ...

class PartialProgramLayer:
    training: bool = ...
    def __init__(
        self, main_program: Any, inputs: Any, outputs: Any, parameters: Optional[Any] = ..., **kwargs: Any
    ) -> None: ...
    def __call__(self, inputs: Any): ...
    def drop_scope_if_no_grad(self) -> None: ...
    @property
    def program(self): ...
    @property
    def program_id(self): ...

def partial_program_from(concrete_program: Any): ...



from __future__ import annotations

from typing import Any, Optional

class MetricBase:
    def __init__(self, name: Any) -> None: ...
    def reset(self) -> None: ...
    def get_config(self): ...
    def update(self, preds: Any, labels: Any) -> None: ...
    def eval(self) -> None: ...

class CompositeMetric(MetricBase):
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def add_metric(self, metric: Any) -> None: ...
    def update(self, preds: Any, labels: Any) -> None: ...
    def eval(self): ...

class Precision(MetricBase):
    tp: int = ...
    fp: int = ...
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def update(self, preds: Any, labels: Any) -> None: ...
    def eval(self): ...

class Recall(MetricBase):
    tp: int = ...
    fn: int = ...
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def update(self, preds: Any, labels: Any) -> None: ...
    def eval(self): ...

class Accuracy(MetricBase):
    value: float = ...
    weight: float = ...
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def update(self, value: Any, weight: Any) -> None: ...
    def eval(self): ...

class ChunkEvaluator(MetricBase):
    num_infer_chunks: int = ...
    num_label_chunks: int = ...
    num_correct_chunks: int = ...
    def __init__(self, name: Optional[Any] = ...) -> None: ...
    def update(self, num_infer_chunks: Any, num_label_chunks: Any, num_correct_chunks: Any) -> None: ...
    def eval(self): ...

class EditDistance(MetricBase):
    total_distance: float = ...
    seq_num: int = ...
    instance_error: int = ...
    def __init__(self, name: Any) -> None: ...
    def update(self, distances: Any, seq_num: Any) -> None: ...
    def eval(self): ...

class Auc(MetricBase):
    def __init__(self, name: Any, curve: str = ..., num_thresholds: int = ...) -> None: ...
    def update(self, preds: Any, labels: Any) -> None: ...
    @staticmethod
    def trapezoid_area(x1: Any, x2: Any, y1: Any, y2: Any): ...
    def eval(self): ...

class DetectionMAP:
    helper: Any = ...
    has_state: Any = ...
    cur_map: Any = ...
    accum_map: Any = ...
    def __init__(
        self,
        input: Any,
        gt_label: Any,
        gt_box: Any,
        gt_difficult: Optional[Any] = ...,
        class_num: Optional[Any] = ...,
        background_label: int = ...,
        overlap_threshold: float = ...,
        evaluate_difficult: bool = ...,
        ap_version: str = ...,
    ) -> None: ...
    def get_map_var(self): ...
    def reset(self, executor: Any, reset_program: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

from ...fluid.layer_helper import LayerHelper as LayerHelper
from .. import Layer as Layer

class AvgPool1D(Layer):
    kernel_size: Any = ...
    stride: Any = ...
    padding: Any = ...
    ceil_mode: Any = ...
    exclusive: Any = ...
    name: Any = ...
    def __init__(
        self,
        kernel_size: Any,
        stride: Optional[Any] = ...,
        padding: int = ...,
        exclusive: bool = ...,
        ceil_mode: bool = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...

class AvgPool2D(Layer):
    ksize: Any = ...
    stride: Any = ...
    padding: Any = ...
    ceil_mode: Any = ...
    exclusive: Any = ...
    divisor: Any = ...
    data_format: Any = ...
    name: Any = ...
    def __init__(
        self,
        kernel_size: Any,
        stride: Optional[Any] = ...,
        padding: int = ...,
        ceil_mode: bool = ...,
        exclusive: bool = ...,
        divisor_override: Optional[Any] = ...,
        data_format: str = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...

class AvgPool3D(Layer):
    ksize: Any = ...
    stride: Any = ...
    padding: Any = ...
    ceil_mode: Any = ...
    exclusive: Any = ...
    divisor: Any = ...
    data_format: Any = ...
    name: Any = ...
    def __init__(
        self,
        kernel_size: Any,
        stride: Optional[Any] = ...,
        padding: int = ...,
        ceil_mode: bool = ...,
        exclusive: bool = ...,
        divisor_override: Optional[Any] = ...,
        data_format: str = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...

class MaxPool1D(Layer):
    kernel_size: Any = ...
    stride: Any = ...
    padding: Any = ...
    ceil_mode: Any = ...
    return_mask: Any = ...
    name: Any = ...
    def __init__(
        self,
        kernel_size: Any,
        stride: Optional[Any] = ...,
        padding: int = ...,
        return_mask: bool = ...,
        ceil_mode: bool = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, input: Any): ...
    def extra_repr(self): ...

class MaxPool2D(Layer):
    ksize: Any = ...
    stride: Any = ...
    padding: Any = ...
    return_mask: Any = ...
    ceil_mode: Any = ...
    data_format: Any = ...
    name: Any = ...
    def __init__(
        self,
        kernel_size: Any,
        stride: Optional[Any] = ...,
        padding: int = ...,
        return_mask: bool = ...,
        ceil_mode: bool = ...,
        data_format: str = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...

class MaxPool3D(Layer):
    ksize: Any = ...
    stride: Any = ...
    padding: Any = ...
    return_mask: Any = ...
    ceil_mode: Any = ...
    data_format: Any = ...
    name: Any = ...
    def __init__(
        self,
        kernel_size: Any,
        stride: Optional[Any] = ...,
        padding: int = ...,
        return_mask: bool = ...,
        ceil_mode: bool = ...,
        data_format: str = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...

class AdaptiveAvgPool1D(Layer):
    output_size: Any = ...
    name: Any = ...
    def __init__(self, output_size: Any, name: Optional[Any] = ...) -> None: ...
    def forward(self, input: Any): ...
    def extra_repr(self): ...

class AdaptiveAvgPool2D(Layer):
    def __init__(self, output_size: Any, data_format: str = ..., name: Optional[Any] = ...) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...

class AdaptiveAvgPool3D(Layer):
    def __init__(self, output_size: Any, data_format: str = ..., name: Optional[Any] = ...) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...

class AdaptiveMaxPool1D(Layer):
    output_size: Any = ...
    return_mask: Any = ...
    name: Any = ...
    def __init__(self, output_size: Any, return_mask: bool = ..., name: Optional[Any] = ...) -> None: ...
    def forward(self, input: Any): ...
    def extra_repr(self): ...

class AdaptiveMaxPool2D(Layer):
    def __init__(self, output_size: Any, return_mask: bool = ..., name: Optional[Any] = ...) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...

class AdaptiveMaxPool3D(Layer):
    def __init__(self, output_size: Any, return_mask: bool = ..., name: Optional[Any] = ...) -> None: ...
    def forward(self, x: Any): ...
    def extra_repr(self): ...

class MaxUnPool1D(Layer):
    ksize: Any = ...
    stride: Any = ...
    padding: Any = ...
    data_format: Any = ...
    output_size: Any = ...
    name: Any = ...
    def __init__(
        self,
        kernel_size: Any,
        stride: Optional[Any] = ...,
        padding: int = ...,
        data_format: str = ...,
        output_size: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any, indices: Any): ...
    def extra_repr(self): ...

class MaxUnPool2D(Layer):
    ksize: Any = ...
    stride: Any = ...
    padding: Any = ...
    data_format: Any = ...
    output_size: Any = ...
    name: Any = ...
    def __init__(
        self,
        kernel_size: Any,
        stride: Optional[Any] = ...,
        padding: int = ...,
        data_format: str = ...,
        output_size: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any, indices: Any): ...
    def extra_repr(self): ...

class MaxUnPool3D(Layer):
    ksize: Any = ...
    stride: Any = ...
    padding: Any = ...
    data_format: Any = ...
    output_size: Any = ...
    name: Any = ...
    def __init__(
        self,
        kernel_size: Any,
        stride: Optional[Any] = ...,
        padding: int = ...,
        data_format: str = ...,
        output_size: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, x: Any, indices: Any): ...
    def extra_repr(self): ...



from __future__ import annotations

from typing import Any, Optional

class ImperativeQuantAware:
    fuse_conv_bn: Any = ...
    def __init__(
        self,
        quantizable_layer_type: Any = ...,
        weight_quantize_type: str = ...,
        activation_quantize_type: str = ...,
        weight_bits: int = ...,
        activation_bits: int = ...,
        moving_rate: float = ...,
        fuse_conv_bn: bool = ...,
        weight_preprocess_layer: Optional[Any] = ...,
        act_preprocess_layer: Optional[Any] = ...,
        weight_quantize_layer: Optional[Any] = ...,
        act_quantize_layer: Optional[Any] = ...,
    ) -> None: ...
    def quantize(self, model: Any): ...
    def save_quantized_model(self, layer: Any, path: Any, input_spec: Optional[Any] = ..., **config: Any) -> None: ...

class ImperativeQuantizeInputs:
    def __init__(
        self,
        quantizable_layer_type: Any = ...,
        weight_quantize_type: str = ...,
        activation_quantize_type: str = ...,
        weight_bits: int = ...,
        activation_bits: int = ...,
        moving_rate: float = ...,
        weight_preprocess_layer: Optional[Any] = ...,
        act_preprocess_layer: Optional[Any] = ...,
        weight_quantize_layer: Optional[Any] = ...,
        act_quantize_layer: Optional[Any] = ...,
    ): ...
    def apply(self, model: Any) -> None: ...

class ImperativeQuantizeOutputs:
    def __init__(self, moving_rate: float = ...) -> None: ...
    def apply(self, model: Any) -> None: ...
    def save_quantized_model(
        self, model: Any, path: Any, input_spec: Optional[Any] = ..., onnx_format: bool = ..., **config: Any
    ) -> None: ...



from __future__ import annotations

from enum import Enum
from typing import Any

from .statistic_helper import *

class SortedKeys(Enum):
    CPUTotal = ...
    CPUAvg = ...
    CPUMax = ...
    CPUMin = ...
    GPUTotal = ...
    GPUAvg = ...
    GPUMax = ...
    GPUMin = ...

class HostStatisticNode:
    hostnode: Any = ...
    children_node: Any = ...
    runtime_node: Any = ...
    cpu_time: int = ...
    self_cpu_time: int = ...
    gpu_time: int = ...
    self_gpu_time: int = ...
    general_gpu_time: int = ...
    self_general_gpu_time: int = ...
    is_terminal_operator_node: bool = ...
    def __init__(self, hostnode: Any) -> None: ...
    def cal_statistic(self) -> None: ...
    @property
    def end_ns(self): ...
    @property
    def start_ns(self): ...
    def __getattr__(self, name: Any): ...

def traverse_tree(nodetrees: Any): ...
def get_device_nodes(hostnode: Any): ...
def wrap_tree(nodetrees: Any): ...

class TimeRangeSummary:
    CPUTimeRange: Any = ...
    GPUTimeRange: Any = ...
    CPUTimeRangeSum: Any = ...
    GPUTimeRangeSum: Any = ...
    call_times: Any = ...
    def __init__(self): ...
    def parse(self, nodetrees: Any): ...
    def get_gpu_devices(self): ...
    def get_gpu_range_sum(self, device_id: Any, event_type: Any): ...
    def get_cpu_range_sum(self, event_type: Any): ...

class DistributedSummary:
    cpu_communication_range: Any = ...
    gpu_communication_range: Any = ...
    communication_range: Any = ...
    computation_range: Any = ...
    overlap_range: Any = ...
    cpu_calls: int = ...
    gpu_calls: int = ...
    def __init__(self) -> None: ...
    def parse(self, nodetrees: Any) -> None: ...

class EventSummary:
    class DeviceItem:
        name: Any = ...
        call: int = ...
        gpu_time: int = ...
        max_gpu_time: int = ...
        min_gpu_time: Any = ...
        def __init__(self, name: Any) -> None: ...
        @property
        def avg_gpu_time(self): ...
        def add_gpu_time(self, time: Any) -> None: ...
        def add_item(self, node: Any) -> None: ...

    class OperatorItem:
        name: Any = ...
        call: int = ...
        cpu_time: int = ...
        gpu_time: int = ...
        max_cpu_time: int = ...
        min_cpu_time: Any = ...
        max_gpu_time: int = ...
        min_gpu_time: Any = ...
        devices: Any = ...
        operator_inners: Any = ...
        general_gpu_time: int = ...
        min_general_gpu_time: Any = ...
        max_general_gpu_time: int = ...
        def __init__(self, name: Any) -> None: ...
        @property
        def avg_cpu_time(self): ...
        @property
        def avg_gpu_time(self): ...
        @property
        def avg_general_gpu_time(self): ...
        def add_cpu_time(self, time: Any) -> None: ...
        def add_gpu_time(self, time: Any) -> None: ...
        def add_general_gpu_time(self, time: Any) -> None: ...
        def add_call(self) -> None: ...
        def add_item(self, node: Any) -> None: ...

    class GeneralItem:
        name: Any = ...
        call: int = ...
        cpu_time: int = ...
        max_cpu_time: int = ...
        min_cpu_time: Any = ...
        gpu_time: int = ...
        max_gpu_time: int = ...
        min_gpu_time: Any = ...
        general_gpu_time: int = ...
        min_general_gpu_time: Any = ...
        max_general_gpu_time: int = ...
        def __init__(self, name: Any) -> None: ...
        @property
        def avg_cpu_time(self): ...
        @property
        def avg_gpu_time(self): ...
        @property
        def avg_general_gpu_time(self): ...
        def add_cpu_time(self, time: Any) -> None: ...
        def add_gpu_time(self, time: Any) -> None: ...
        def add_general_gpu_time(self, time: Any) -> None: ...
        def add_call(self) -> None: ...
        def add_item(self, node: Any) -> None: ...
    items: Any = ...
    thread_items: Any = ...
    userdefined_items: Any = ...
    userdefined_thread_items: Any = ...
    model_perspective_items: Any = ...
    memory_manipulation_items: Any = ...
    kernel_items: Any = ...
    def __init__(self) -> None: ...
    def parse(self, nodetrees: Any) -> None: ...
    def add_operator_item(self, operator_node: Any) -> None: ...
    def add_userdefined_item(self, userdefined_node: Any) -> None: ...
    def add_memory_manipulation_item(self, memory_manipulation_node: Any) -> None: ...
    def add_model_perspective_item(self, model_perspective_node: Any) -> None: ...
    def add_kernel_item(self, root_node: Any) -> None: ...

class StatisticData:
    node_trees: Any = ...
    extra_info: Any = ...
    time_range_summary: Any = ...
    event_summary: Any = ...
    distributed_summary: Any = ...
    def __init__(self, node_trees: Any, extra_info: Any) -> None: ...



from __future__ import annotations

import unittest

from paddle.fluid.dygraph.container import Sequential as Sequential
from paddle.nn import Linear as Linear
from paddle.nn import Softmax as Softmax

class TestImperativeQat(unittest.TestCase):
    weight_quantize_type: str = ...
    activation_quantize_type: str = ...
    onnx_format: bool = ...
    check_export_model_accuracy: bool = ...
    diff_threshold: float = ...
    fuse_conv_bn: bool = ...
    def set_vars(self) -> None: ...
    def func_qat(self) -> None: ...
    def test_qat(self) -> None: ...

class TestImperativeQatONNXFormat(unittest.TestCase):
    weight_quantize_type: str = ...
    activation_quantize_type: str = ...
    onnx_format: bool = ...
    diff_threshold: float = ...
    fuse_conv_bn: bool = ...
    def set_vars(self) -> None: ...



from __future__ import annotations

import collections
from typing import Any, Optional

from numpy import cos as cos
from numpy import sin as sin
from numpy import tan as tan

def to_tensor(pic: Any, data_format: str = ...): ...
def resize(img: Any, size: Any, interpolation: str = ...): ...
def pad(img: Any, padding: Any, fill: int = ..., padding_mode: str = ...): ...
def crop(img: Any, top: Any, left: Any, height: Any, width: Any): ...
def center_crop(img: Any, output_size: Any): ...
def hflip(img: Any): ...
def vflip(img: Any): ...
def adjust_brightness(img: Any, brightness_factor: Any): ...
def adjust_contrast(img: Any, contrast_factor: Any): ...
def adjust_saturation(img: Any, saturation_factor: Any): ...
def adjust_hue(img: Any, hue_factor: Any): ...
def rotate(
    img: Any, angle: Any, interpolation: str = ..., expand: bool = ..., center: Optional[Any] = ..., fill: int = ...
): ...
def to_grayscale(img: Any, num_output_channels: int = ...): ...
def normalize(img: Any, mean: Any, std: Any, data_format: str = ..., to_rgb: bool = ...): ...



from __future__ import annotations

from typing import Any

from . import average as average
from . import backward as backward
from . import clip as clip
from . import compiler as compiler
from . import contrib as contrib
from . import data_feed_desc as data_feed_desc
from . import dataset as dataset
from . import distribute_lookup_table as distribute_lookup_table
from . import dygraph as dygraph
from . import evaluator as evaluator
from . import executor as executor
from . import framework as framework
from . import generator as generator
from . import incubate as incubate
from . import initializer as initializer
from . import install_check as install_check
from . import io as io
from . import layers as layers
from . import metrics as metrics
from . import nets as nets
from . import optimizer as optimizer
from . import parallel_executor as parallel_executor
from . import profiler as profiler
from . import regularizer as regularizer
from . import trainer_desc as trainer_desc
from . import transpiler as transpiler
from . import unique_name as unique_name
from .backward import append_backward as append_backward
from .backward import gradients as gradients
from .compiler import *
from .data import *
from .data_feed_desc import *
from .data_feeder import DataFeeder as DataFeeder
from .dataset import *
from .dygraph.base import disable_dygraph as disable_dygraph
from .dygraph.base import enable_dygraph as enable_dygraph
from .dygraph.checkpoint import load_dygraph as load_dygraph
from .dygraph.checkpoint import save_dygraph as save_dygraph
from .dygraph.layers import *
from .dygraph.nn import *
from .dygraph.varbase_patch_methods import monkey_patch_varbase as monkey_patch_varbase
from .executor import *
from .framework import *
from .generator import Generator as Generator
from .incubate import fleet as fleet
from .initializer import set_global_initializer as set_global_initializer
from .input import embedding as embedding
from .input import one_hot as one_hot
from .io import load as load
from .io import load_program_state as load_program_state
from .io import save as save
from .io import set_program_state as set_program_state
from .lod_tensor import create_lod_tensor as create_lod_tensor
from .lod_tensor import create_random_int_lodtensor as create_random_int_lodtensor
from .parallel_executor import *
from .param_attr import ParamAttr as ParamAttr
from .param_attr import WeightNormParamAttr as WeightNormParamAttr
from .trainer_desc import DistMultiTrainer as DistMultiTrainer
from .trainer_desc import HeterPipelineTrainer as HeterPipelineTrainer
from .trainer_desc import HeterXpuTrainer as HeterXpuTrainer
from .trainer_desc import MultiTrainer as MultiTrainer
from .trainer_desc import PipelineTrainer as PipelineTrainer
from .trainer_desc import TrainerDesc as TrainerDesc
from .transpiler import DistributeTranspiler as DistributeTranspiler
from .transpiler import DistributeTranspilerConfig as DistributeTranspilerConfig
from .transpiler import HashName as HashName
from .transpiler import RoundRobin as RoundRobin
from .transpiler import memory_optimize as memory_optimize
from .transpiler import release_memory as release_memory

core_suffix: str
legacy_core: Any
Tensor = LoDTensor
enable_imperative = enable_dygraph
disable_imperative = disable_dygraph

def __bootstrap__() -> None: ...



from __future__ import annotations

from typing import Any

from paddle.distributed.fleet.launch_utils import DistributeMode as DistributeMode

from .collective import CollectiveLauncher as CollectiveLauncher
from .manager import ELASTIC_EXIT_CODE as ELASTIC_EXIT_CODE
from .manager import ElasticLevel as ElasticLevel
from .manager import ElasticManager as ElasticManager
from .manager import ElasticStatus as ElasticStatus

def enable_elastic(args: Any, distribute_mode: Any): ...
def launch_elastic(args: Any, distribute_mode: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

from paddle.fluid.initializer import Constant as Constant
from paddle.optimizer import Optimizer

class DistributedFusedLamb(Optimizer):
    helper: Any = ...
    def __init__(
        self,
        learning_rate: float = ...,
        lamb_weight_decay: float = ...,
        beta1: float = ...,
        beta2: float = ...,
        epsilon: float = ...,
        parameters: Optional[Any] = ...,
        grad_clip: Optional[Any] = ...,
        exclude_from_weight_decay_fn: Optional[Any] = ...,
        clip_after_allreduce: bool = ...,
        is_grad_scaled_by_nranks: bool = ...,
        alignment: int = ...,
        use_master_param_norm: bool = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def apply_optimize(self, params_grads: Any) -> None: ...
    def apply_gradients(self, params_grads: Any) -> None: ...



from __future__ import annotations

from typing import Any

core_suffix: str
has_avx_core: bool
has_noavx_core: bool
current_path: Any
third_lib_path: Any
executable_path: Any
VarBase = Any

def avx_supported(): ...
def run_shell_command(cmd: Any): ...
def get_dso_path(core_so: Any, dso_name: Any): ...
def load_dso(dso_absolute_path: Any) -> None: ...
def pre_load(dso_name: Any) -> None: ...
def get_libc_ver(): ...
def less_than_ver(a: Any, b: Any): ...

libc_type: Any
libc_ver: Any
load_noavx: bool

def set_paddle_custom_device_lib_path(lib_path: Any) -> None: ...
def set_paddle_lib_path() -> None: ...

class TracerEventType: ...



from __future__ import annotations

from typing import Optional

from . import Tensor

def stft(
    x: Tensor,
    n_fft: int,
    hop_length: Optional[int] = ...,
    win_length: Optional[int] = ...,
    window: Optional[Tensor] = ...,
    center: bool = ...,
    pad_mode: str = ...,
    normalized: bool = ...,
    onesided: bool = ...,
    name: Optional[str] = ...,
) -> Tensor: ...
def istft(
    x: Tensor,
    n_fft: int,
    hop_length: Optional[int] = ...,
    win_length: Optional[int] = ...,
    window: Optional[Tensor] = ...,
    center: bool = ...,
    normalized: bool = ...,
    onesided: bool = ...,
    length: Optional[int] = ...,
    return_complex: bool = ...,
    name: Optional[str] = ...,
) -> Tensor: ...



from __future__ import annotations

from typing import Any, Optional

def auto_cast(
    enable: bool = ...,
    custom_white_list: Optional[Any] = ...,
    custom_black_list: Optional[Any] = ...,
    level: str = ...,
    dtype: str = ...,
): ...
def decorate(
    models: Any,
    optimizers: Optional[Any] = ...,
    level: str = ...,
    master_weight: Optional[Any] = ...,
    save_dtype: Optional[Any] = ...,
): ...



from __future__ import annotations

from typing import Any

class WeightedAverage:
    def __init__(self) -> None: ...
    numerator: Any = ...
    denominator: Any = ...
    def reset(self) -> None: ...
    def add(self, value: Any, weight: Any) -> None: ...
    def eval(self): ...



from __future__ import annotations

from typing import Any, Optional

class DatasetFactory:
    def __init__(self) -> None: ...
    def create_dataset(self, datafeed_class: str = ...): ...

class DatasetBase:
    proto_desc: Any = ...
    dataset: Any = ...
    thread_num: int = ...
    filelist: Any = ...
    use_ps_gpu: bool = ...
    psgpu: Any = ...
    def __init__(self) -> None: ...
    def set_pipe_command(self, pipe_command: Any) -> None: ...
    def set_so_parser_name(self, so_parser_name: Any) -> None: ...
    def set_rank_offset(self, rank_offset: Any) -> None: ...
    fea_eval: Any = ...
    def set_fea_eval(self, record_candidate_size: Any, fea_eval: bool = ...) -> None: ...
    def slots_shuffle(self, slots: Any) -> None: ...
    def set_batch_size(self, batch_size: Any) -> None: ...
    def set_pv_batch_size(self, pv_batch_size: Any) -> None: ...
    def set_thread(self, thread_num: Any) -> None: ...
    def set_filelist(self, filelist: Any) -> None: ...
    def set_input_type(self, input_type: Any) -> None: ...
    def set_use_var(self, var_list: Any) -> None: ...
    def set_hdfs_config(self, fs_name: Any, fs_ugi: Any) -> None: ...
    def set_download_cmd(self, download_cmd: Any) -> None: ...
    def desc(self): ...

class InMemoryDataset(DatasetBase):
    fleet_send_batch_size: Any = ...
    is_user_set_queue_num: bool = ...
    queue_num: Any = ...
    parse_ins_id: bool = ...
    parse_content: bool = ...
    parse_logkey: bool = ...
    merge_by_sid: bool = ...
    enable_pv_merge: bool = ...
    merge_by_lineid: bool = ...
    fleet_send_sleep_seconds: Any = ...
    trainer_num: int = ...
    def __init__(self) -> None: ...
    dataset: Any = ...
    def set_feed_type(self, data_feed_type: Any) -> None: ...
    def set_queue_num(self, queue_num: Any) -> None: ...
    def set_parse_ins_id(self, parse_ins_id: Any) -> None: ...
    def set_parse_content(self, parse_content: Any) -> None: ...
    def set_parse_logkey(self, parse_logkey: Any) -> None: ...
    def set_merge_by_sid(self, merge_by_sid: Any) -> None: ...
    def set_enable_pv_merge(self, enable_pv_merge: Any) -> None: ...
    def preprocess_instance(self) -> None: ...
    def set_current_phase(self, current_phase: Any) -> None: ...
    def postprocess_instance(self) -> None: ...
    def set_fleet_send_batch_size(self, fleet_send_batch_size: int = ...) -> None: ...
    def set_fleet_send_sleep_seconds(self, fleet_send_sleep_seconds: int = ...) -> None: ...
    def set_merge_by_lineid(self, merge_size: int = ...) -> None: ...
    gen_uni_feasigns: Any = ...
    local_shard_num: Any = ...
    def set_generate_unique_feasigns(self, generate_uni_feasigns: Any, shard_num: Any) -> None: ...
    def generate_local_tables_unlock(
        self, table_id: Any, fea_dim: Any, read_thread_num: Any, consume_thread_num: Any, shard_num: Any
    ) -> None: ...
    def set_date(self, date: Any) -> None: ...
    def load_into_memory(self, is_shuffle: bool = ...) -> None: ...
    def preload_into_memory(self, thread_num: Optional[Any] = ...) -> None: ...
    def wait_preload_done(self) -> None: ...
    def local_shuffle(self) -> None: ...
    def global_shuffle(self, fleet: Optional[Any] = ..., thread_num: int = ...) -> None: ...
    def release_memory(self) -> None: ...
    def get_pv_data_size(self): ...
    def get_memory_data_size(self, fleet: Optional[Any] = ...): ...
    def get_shuffle_data_size(self, fleet: Optional[Any] = ...): ...

class QueueDataset(DatasetBase):
    def __init__(self) -> None: ...
    def local_shuffle(self) -> None: ...
    def global_shuffle(self, fleet: Optional[Any] = ...) -> None: ...

class FileInstantDataset(DatasetBase):
    def __init__(self) -> None: ...
    def local_shuffle(self) -> None: ...
    def global_shuffle(self, fleet: Optional[Any] = ...) -> None: ...

class BoxPSDataset(InMemoryDataset):
    boxps: Any = ...
    def __init__(self) -> None: ...
    def set_date(self, date: Any) -> None: ...
    def begin_pass(self) -> None: ...
    def end_pass(self, need_save_delta: Any) -> None: ...
    def wait_preload_done(self) -> None: ...
    def load_into_memory(self) -> None: ...
    def preload_into_memory(self) -> None: ...
    def slots_shuffle(self, slots: Any) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.distribution import distribution

class Multinomial(distribution.Distribution):
    probs: Any = ...
    total_count: Any = ...
    def __init__(self, total_count: Any, probs: Any) -> None: ...
    @property
    def mean(self): ...
    @property
    def variance(self): ...
    def prob(self, value: Any): ...
    def log_prob(self, value: Any): ...
    def sample(self, shape: Any = ...): ...
    def entropy(self): ...



from __future__ import annotations

from ast import AST
from typing import Any

from .ast3 import ast_to_gast as ast_to_gast
from .ast3 import gast_to_ast as gast_to_ast

class TypeIgnore(AST): ...

py_version: Any

def parse(*args: Any, **kwargs: Any): ...
def literal_eval(node_or_string: Any): ...
def get_docstring(node: Any, clean: bool = ...): ...
def copy_location(new_node: Any, old_node: Any): ...
def fix_missing_locations(node: Any): ...
def increment_lineno(node: Any, n: int = ...): ...



from __future__ import annotations

from contextlib import ContextDecorator
from typing import Any

from paddle.fluid.core import TracerEventType

class RecordEvent(ContextDecorator):
    name: Any = ...
    event_type: Any = ...
    event: Any = ...
    def __init__(self, name: str, event_type: TracerEventType = ...) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type: Any, exc_value: Any, traceback: Any) -> Any: ...
    def begin(self) -> None: ...
    def end(self) -> None: ...

def load_profiler_result(filename: str) -> Any: ...
def in_profiler_mode(): ...
def wrap_optimizers(): ...



from __future__ import annotations

from .graph_khop_sampler import graph_khop_sampler as graph_khop_sampler
from .graph_reindex import graph_reindex as graph_reindex
from .graph_sample_neighbors import graph_sample_neighbors as graph_sample_neighbors
from .graph_send_recv import graph_send_recv as graph_send_recv
from .resnet_unit import ResNetUnit as ResNetUnit
from .softmax_mask_fuse import softmax_mask_fuse as softmax_mask_fuse
from .softmax_mask_fuse_upper_triangle import (
    softmax_mask_fuse_upper_triangle as softmax_mask_fuse_upper_triangle,
)



from __future__ import annotations

from sys import version as version
from typing import Any

from paddle.distributed.fleet.launch_utils import *

def get_cluster_from_args(args: Any, device_mode: Any, devices_per_proc: Any): ...
def cpuonly_check(args: Any): ...
def get_cluster_info(args: Any): ...
def get_global_envs(args: Any, tmp_dir: Any): ...
def launch_collective(args: Any) -> None: ...
def launch_ps(args: Any, distribute_mode: Any) -> None: ...
def infer_backend(args: Any) -> None: ...
def which_distributed_mode(args: Any): ...
def launch() -> None: ...



from __future__ import annotations

from typing import Any, Optional

class ProgramStats:
    block: Any = ...
    ops: Any = ...
    op_deps: Any = ...
    var_op_deps: Any = ...
    def __init__(self, block: Any, ops: Any) -> None: ...
    def get_input_nodes(self): ...
    def get_reserved_vars(self): ...
    def get_out_of_subgraph_vars(self, begin_op_idx: Any, end_op_idx: Any): ...
    def is_subgraph(self, var_group1: Any, var_group2: Any): ...
    def build_stats(self) -> None: ...
    def sort_checkpoints(self, checkpoints_name: Any): ...
    def modify_forward_desc_for_recompute(self) -> None: ...

def append_backward(
    loss: Any,
    parameter_list: Optional[Any] = ...,
    no_grad_set: Optional[Any] = ...,
    callbacks: Optional[Any] = ...,
    checkpoints: Optional[Any] = ...,
    distop_context: Optional[Any] = ...,
): ...
def gradients(targets: Any, inputs: Any, target_gradients: Optional[Any] = ..., no_grad_set: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

class NodeVarType:
    ERROR: int = ...
    UNKNOWN: int = ...
    STATEMENT: int = ...
    CALLABLE: int = ...
    NONE: int = ...
    BOOLEAN: int = ...
    INT: int = ...
    FLOAT: int = ...
    STRING: int = ...
    TENSOR: int = ...
    NUMPY_NDARRAY: int = ...
    LIST: int = ...
    SET: int = ...
    DICT: int = ...
    PADDLE_DYGRAPH_API: int = ...
    PADDLE_CONTROL_IF: int = ...
    PADDLE_CONTROL_WHILE: int = ...
    PADDLE_CONTROL_FOR: int = ...
    PADDLE_RETURN_TYPES: int = ...
    TENSOR_TYPES: Any = ...
    Annotation_map: Any = ...
    @staticmethod
    def binary_op_output_type(in_type1: Any, in_type2: Any): ...
    @staticmethod
    def type_from_annotation(annotation: Any): ...

class AstNodeWrapper:
    node: Any = ...
    parent: Any = ...
    children: Any = ...
    node_var_type: Any = ...
    def __init__(self, node: Any) -> None: ...

class AstVarScope:
    SCOPE_TYPE_SCRIPT: int = ...
    SCOPE_TYPE_FUNCTION: int = ...
    SCOPE_TYPE_CLASS: int = ...
    sub_scopes: Any = ...
    name_to_id: Any = ...
    id_to_type: Any = ...
    cur_id: int = ...
    scope_name: Any = ...
    scope_type: Any = ...
    parent_scope: Any = ...
    def __init__(self, scope_name: str = ..., scope_type: Any = ..., parent_scope: Optional[Any] = ...) -> None: ...
    def add_var_type(self, var_name: Any, node_var_type: Any) -> None: ...
    def set_var_type(self, var_name: Any, node_var_type: Any) -> None: ...
    def get_var_type(self, var_name: Any): ...

class AstVarEnv:
    cur_scope: Any = ...
    def __init__(self) -> None: ...
    def enter_scope(self, scope_name: Any, scope_type: Any): ...
    def exit_scope(self): ...
    def get_parent_scope(self): ...
    def add_var_type(self, var_name: Any, node_var_type: Any) -> None: ...
    def set_var_type(self, var_name: Any, node_var_type: Any) -> None: ...
    def get_var_type(self, var_name: Any): ...
    def get_scope_var_type(self): ...

class StaticAnalysisVisitor:
    def __init__(self, ast_root: Optional[Any] = ...) -> None: ...
    node_wrapper_root: Any = ...
    ancestor_wrappers: Any = ...
    node_to_wrapper_map: Any = ...
    var_env: Any = ...
    def run(self, ast_root: Any) -> None: ...
    def dfs_visit(self, node: Any): ...
    def get_node_wrapper_root(self): ...
    def get_node_to_wrapper_map(self): ...
    def get_var_env(self): ...
    def is_tensor_node(self, node: Any): ...



from __future__ import annotations

from typing import Any, Optional

class _DecoderType:
    TRAINING: int = ...
    BEAM_SEARCH: int = ...

class InitState:
    def __init__(
        self,
        init: Optional[Any] = ...,
        shape: Optional[Any] = ...,
        value: float = ...,
        init_boot: Optional[Any] = ...,
        need_reorder: bool = ...,
        dtype: str = ...,
    ) -> None: ...
    @property
    def value(self): ...
    @property
    def need_reorder(self): ...

class _MemoryState:
    def __init__(self, state_name: Any, rnn_obj: Any, init_state: Any) -> None: ...
    def get_state(self): ...
    def update_state(self, state: Any) -> None: ...

class _ArrayState:
    def __init__(self, state_name: Any, block: Any, init_state: Any) -> None: ...
    def get_state(self): ...
    def update_state(self, state: Any) -> None: ...

class StateCell:
    def __init__(self, inputs: Any, states: Any, out_state: Any, name: Optional[Any] = ...) -> None: ...
    def get_state(self, state_name: Any): ...
    def get_input(self, input_name: Any): ...
    def set_state(self, state_name: Any, state_value: Any) -> None: ...
    def state_updater(self, updater: Any): ...
    def compute_state(self, inputs: Any) -> None: ...
    def update_states(self) -> None: ...
    def out_state(self): ...

class TrainingDecoder:
    BEFORE_DECODER: int = ...
    IN_DECODER: int = ...
    AFTER_DECODER: int = ...
    def __init__(self, state_cell: Any, name: Optional[Any] = ...) -> None: ...
    def block(self) -> None: ...
    @property
    def state_cell(self): ...
    @property
    def dynamic_rnn(self): ...
    @property
    def type(self): ...
    def step_input(self, x: Any): ...
    def static_input(self, x: Any): ...
    def __call__(self, *args: Any, **kwargs: Any): ...
    def output(self, *outputs: Any) -> None: ...

class BeamSearchDecoder:
    BEFORE_BEAM_SEARCH_DECODER: int = ...
    IN_BEAM_SEARCH_DECODER: int = ...
    AFTER_BEAM_SEARCH_DECODER: int = ...
    def __init__(
        self,
        state_cell: Any,
        init_ids: Any,
        init_scores: Any,
        target_dict_dim: Any,
        word_dim: Any,
        input_var_dict: Any = ...,
        topk_size: int = ...,
        sparse_emb: bool = ...,
        max_len: int = ...,
        beam_size: int = ...,
        end_id: int = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def block(self) -> None: ...
    @property
    def type(self): ...
    def early_stop(self) -> None: ...
    def decode(self) -> None: ...
    def read_array(self, init: Any, is_ids: bool = ..., is_scores: bool = ...): ...
    def update_array(self, array: Any, value: Any) -> None: ...
    def __call__(self): ...
    @property
    def state_cell(self): ...



from __future__ import annotations

from typing import Any

int_type = int
long_type = int

def to_text(obj: Any, encoding: str = ..., inplace: bool = ...): ...
def to_bytes(obj: Any, encoding: str = ..., inplace: bool = ...): ...
def round(x: Any, d: int = ...): ...
def floor_division(x: Any, y: Any): ...
def get_exception_message(exc: Any): ...



from __future__ import annotations

from typing import Any, Optional

from .master import Master as Master

class ControleMode:
    COLLECTIVE: str = ...
    PS: str = ...

class ControllerBase:
    ctx: Any = ...
    master: Any = ...
    job: Any = ...
    pod: Any = ...
    join_server: Any = ...
    def __init__(self, ctx: Any) -> None: ...
    def deploy_pod(self) -> None: ...
    def run(self) -> None: ...
    def watch(self) -> bool: ...
    def stop(self, sigint: Optional[Any] = ...) -> None: ...
    def finalize(self) -> None: ...
    sigint: Any = ...
    def signal_handler(self, sigint: Any, frame: Any) -> None: ...

class Controller(ControllerBase):
    def build_job(self) -> None: ...
    def build_pod(self) -> bool: ...
    def new_container(
        self,
        entrypoint: Optional[Any] = ...,
        envs: Any = ...,
        use_ctx_env: bool = ...,
        out: Optional[Any] = ...,
        err: Optional[Any] = ...,
    ): ...
    def add_container(
        self,
        container: Optional[Any] = ...,
        entrypoint: Optional[Any] = ...,
        envs: Any = ...,
        log_tag: Optional[Any] = ...,
        is_init: bool = ...,
    ) -> None: ...
    def pod_replicas(self): ...
    def save_pod_log(self, info: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def center_loss(input: Any, label: Any, num_classes: Any, alpha: Any, param_attr: Any, update_center: bool = ...): ...
def bpr_loss(input: Any, label: Any, name: Optional[Any] = ...): ...
def cross_entropy(input: Any, label: Any, soft_label: bool = ..., ignore_index: Any = ...): ...
def square_error_cost(input: Any, label: Any): ...
def edit_distance(
    input: Any,
    label: Any,
    normalized: bool = ...,
    ignored_tokens: Optional[Any] = ...,
    input_length: Optional[Any] = ...,
    label_length: Optional[Any] = ...,
): ...
def warpctc(
    input: Any,
    label: Any,
    blank: int = ...,
    norm_by_times: bool = ...,
    input_length: Optional[Any] = ...,
    label_length: Optional[Any] = ...,
): ...
def nce(
    input: Any,
    label: Any,
    num_total_classes: Any,
    sample_weight: Optional[Any] = ...,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    num_neg_samples: Optional[Any] = ...,
    name: Optional[Any] = ...,
    sampler: str = ...,
    custom_dist: Optional[Any] = ...,
    seed: int = ...,
    is_sparse: bool = ...,
): ...
def hsigmoid(
    input: Any,
    label: Any,
    num_classes: Any,
    param_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    name: Optional[Any] = ...,
    path_table: Optional[Any] = ...,
    path_code: Optional[Any] = ...,
    is_custom: bool = ...,
    is_sparse: bool = ...,
): ...
def sampled_softmax_with_cross_entropy(
    logits: Any,
    label: Any,
    num_samples: Any,
    num_true: int = ...,
    remove_accidental_hits: bool = ...,
    use_customized_samples: bool = ...,
    customized_samples: Optional[Any] = ...,
    customized_probabilities: Optional[Any] = ...,
    seed: int = ...,
): ...
def softmax_with_cross_entropy(
    logits: Any,
    label: Any,
    soft_label: bool = ...,
    ignore_index: Any = ...,
    numeric_stable_mode: bool = ...,
    return_softmax: bool = ...,
    axis: int = ...,
): ...
def rank_loss(label: Any, left: Any, right: Any, name: Optional[Any] = ...): ...
def margin_rank_loss(label: Any, left: Any, right: Any, margin: float = ..., name: Optional[Any] = ...): ...
def sigmoid_cross_entropy_with_logits(
    x: Any, label: Any, ignore_index: Any = ..., name: Optional[Any] = ..., normalize: bool = ...
): ...
def teacher_student_sigmoid_loss(
    input: Any, label: Any, soft_max_up_bound: float = ..., soft_max_lower_bound: Any = ...
): ...
def huber_loss(input: Any, label: Any, delta: Any): ...
def kldiv_loss(x: Any, target: Any, reduction: str = ..., name: Optional[Any] = ...): ...
def npair_loss(anchor: Any, positive: Any, labels: Any, l2_reg: float = ...): ...
def mse_loss(input: Any, label: Any): ...



from __future__ import annotations

from typing import Any, Optional

class ImperativePTQ:
    def __init__(self, quant_config: Any = ...) -> None: ...
    def quantize(self, model: Any, inplace: bool = ..., fuse: bool = ..., fuse_list: Optional[Any] = ...): ...
    def save_quantized_model(self, model: Any, path: Any, input_spec: Optional[Any] = ..., **config: Any) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def vjp(func: Any, xs: Any, v: Optional[Any] = ...): ...
def jvp(func: Any, xs: Any, v: Optional[Any] = ...): ...

class Jacobian:
    def __init__(self, func: Any, xs: Any, is_batched: bool = ...) -> None: ...
    def __getitem__(self, indexes: Any): ...
    @property
    def shape(self): ...

class Hessian:
    symbolic: Any = ...
    def __init__(self, func: Any, xs: Any, is_batched: bool = ...): ...
    def __getitem__(self, indexes: Any): ...
    @property
    def shape(self): ...

class _Jacobian:
    def __init__(self, func: Any, xs: Any) -> None: ...
    @property
    def shape(self) -> None: ...
    def __getitem__(self, indexes: Any): ...

class _JacobianNoBatch(_Jacobian):
    def __init__(self, func: Any, xs: Any) -> None: ...
    @property
    def shape(self): ...

class _JacobianBatchLast(_Jacobian):
    def __init__(self, func: Any, xs: Any) -> None: ...
    @property
    def shape(self): ...

class _JacobianBatchFirst(_Jacobian):
    def __init__(self, func: Any, xs: Any) -> None: ...
    @property
    def shape(self): ...

def jacobian(func: Any, inputs: Any, create_graph: bool = ..., allow_unused: bool = ...): ...
def batch_jacobian(func: Any, inputs: Any, create_graph: bool = ..., allow_unused: bool = ...): ...
def batch_hessian(func: Any, inputs: Any, create_graph: bool = ..., allow_unused: bool = ...): ...
def hessian(func: Any, inputs: Any, create_graph: bool = ..., allow_unused: bool = ...): ...
def vhp(func: Any, inputs: Any, v: Optional[Any] = ..., create_graph: bool = ..., allow_unused: bool = ...): ...



from __future__ import annotations

from collections import namedtuple
from typing import Any, Optional

from paddle.fluid.optimizer import Optimizer

from . import ascend_parser as ascend_parser

HcomGroupConfig = namedtuple("HcomGroupConfig", ["name", "nranks", "rank_ids"])

class AscendIRParser:
    graph_idx: int = ...
    hcom_endpoints: Any = ...
    groups_to_create: Any = ...
    def __init__(self, auto_dp: bool = ..., world_rank_size: int = ...) -> None: ...
    def parse_op(self, op: Any) -> None: ...
    def parse_program(self, startup_program: Any, main_program: Any, input_varlist: Any, fetch_list: Any): ...

class AscendOptimizer(Optimizer):
    inner_opt: Any = ...
    fetch_list: Any = ...
    ascend_instance: Any = ...
    def __init__(self, optimizer: Any, fetch_list: Any = ...) -> None: ...
    def __del__(self) -> None: ...
    parser: Any = ...
    def minimize(
        self,
        loss: Any,
        startup_program: Optional[Any] = ...,
        parameter_list: Optional[Any] = ...,
        no_grad_set: Optional[Any] = ...,
        auto_dp: bool = ...,
        rank_table_file: Optional[Any] = ...,
        precision_mode: str = ...,
    ): ...



from __future__ import annotations

from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    create_bool_as_type as create_bool_as_type,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    create_fill_constant_node as create_fill_constant_node,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    create_static_variable_gast_node as create_static_variable_gast_node,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    data_layer_not_check as data_layer_not_check,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    to_static_variable as to_static_variable,
)
from ...fluid.dygraph.dygraph_to_static.variable_trans_func import (
    to_static_variable_gast_node as to_static_variable_gast_node,
)



from __future__ import annotations

from datetime import timedelta as timedelta
from typing import Any, Optional

from ..fluid.data_feeder import check_dtype as check_dtype
from ..fluid.data_feeder import check_type as check_type
from ..fluid.data_feeder import check_variable_and_dtype as check_variable_and_dtype
from ..fluid.data_feeder import convert_dtype as convert_dtype
from ..fluid.dygraph import layers as layers
from ..fluid.dygraph.parallel import prepare_context as prepare_context
from ..fluid.framework import OpProtoHolder as OpProtoHolder
from ..fluid.framework import Variable as Variable
from ..fluid.framework import convert_np_dtype_to_dtype_ as convert_np_dtype_to_dtype_
from ..fluid.framework import in_dygraph_mode as in_dygraph_mode
from ..fluid.layer_helper import LayerHelper as LayerHelper
from ..fluid.layers import utils as utils
from ..fluid.layers.tensor import fill_constant as fill_constant

class ReduceOp:
    SUM: int = ...
    MAX: int = ...
    MIN: int = ...
    PROD: int = ...
    AVG: int = ...

class Group:
    rank: Any = ...
    nranks: Any = ...
    id: Any = ...
    ranks: Any = ...
    pg: Any = ...
    name: Any = ...
    def __init__(
        self,
        rank: Any,
        rank_num: Any,
        id: int = ...,
        ranks: Any = ...,
        pg: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def is_member(self): ...
    def get_group_rank(self, rank: Any): ...
    @property
    def process_group(self): ...

def get_group(id: int = ...): ...
def barrier(group: Optional[Any] = ...): ...
def new_group(ranks: Optional[Any] = ..., backend: Optional[Any] = ...): ...
def wait(tensor: Any, group: Optional[Any] = ..., use_calc_stream: bool = ...) -> None: ...
def broadcast(tensor: Any, src: Any, group: Optional[Any] = ..., use_calc_stream: bool = ...): ...
def all_reduce(tensor: Any, op: Any = ..., group: Optional[Any] = ..., use_calc_stream: bool = ...): ...
def reduce(tensor: Any, dst: Any, op: Any = ..., group: Optional[Any] = ..., use_calc_stream: bool = ...): ...
def all_gather(tensor_list: Any, tensor: Any, group: Optional[Any] = ..., use_calc_stream: bool = ...) -> None: ...
def scatter(
    tensor: Any,
    tensor_list: Optional[Any] = ...,
    src: int = ...,
    group: Optional[Any] = ...,
    use_calc_stream: bool = ...,
): ...

class _Linear(layers.Layer):
    weight: Any = ...
    bias: Any = ...
    name: Any = ...
    def __init__(
        self,
        in_features: Any,
        out_features: Any,
        weight_attr: Optional[Any] = ...,
        bias_attr: Optional[Any] = ...,
        name: Optional[Any] = ...,
    ) -> None: ...
    def forward(self, input: Any): ...
    def extra_repr(self): ...

def split(
    x: Any,
    size: Any,
    operation: Any,
    axis: int = ...,
    num_partitions: int = ...,
    gather_out: bool = ...,
    weight_attr: Optional[Any] = ...,
    bias_attr: Optional[Any] = ...,
    name: Optional[Any] = ...,
): ...
def alltoall(
    in_tensor_list: Any, out_tensor_list: Any, group: Optional[Any] = ..., use_calc_stream: bool = ...
) -> None: ...
def send(tensor: Any, dst: int = ..., group: Optional[Any] = ..., use_calc_stream: bool = ...): ...
def recv(tensor: Any, src: int = ..., group: Optional[Any] = ..., use_calc_stream: bool = ...): ...



from __future__ import annotations

from typing import Any, Optional

from .... import core as core
from .... import unique_name as unique_name
from ....executor import global_scope as global_scope
from ....framework import Operator as Operator
from ....framework import Program as Program
from ....framework import Variable as Variable
from ....framework import program_guard as program_guard
from ....initializer import Constant as Constant
from ....layer_helper import LayerHelper as LayerHelper
from ....log_helper import get_logger as get_logger
from ....param_attr import ParamAttr as ParamAttr

def find_next_ops(block: Any, var_name: Any): ...
def load_variable_data(scope: Any, var_name: Any): ...

class QuantizeTranspilerV2:
    def __init__(
        self,
        weight_bits: int = ...,
        activation_bits: int = ...,
        weight_quantize_type: str = ...,
        activation_quantize_type: str = ...,
        quantizable_op_type: Any = ...,
        skip_pattern: Any = ...,
    ) -> None: ...
    def apply(self, program: Any, startup_program: Any, is_test: bool = ...) -> None: ...
    def convert(self, test_program: Any, scope: Optional[Any] = ...) -> None: ...



from __future__ import annotations

import unittest
from typing import Any

def conv_net(img: Any, label: Any): ...

class TestQuantizeProgramPass(unittest.TestCase):
    def quantize_program(
        self,
        use_cuda: Any,
        seed: Any,
        activation_quant_type: str = ...,
        weight_quant_type: str = ...,
        for_ci: bool = ...,
    ): ...
    def test_gpu_1(self) -> None: ...
    def test_gpu_2(self) -> None: ...
    def test_cpu_1(self) -> None: ...
    def test_cpu_2(self) -> None: ...



from __future__ import annotations

from typing import Any, Optional

def set_image_backend(backend: Any) -> None: ...
def get_image_backend(): ...
def image_load(path: Any, backend: Optional[Any] = ...): ...



from __future__ import annotations

from typing import Any, Optional

class ProcessContext:
    def __init__(
        self,
        cmd: Any,
        env: Any = ...,
        out: Any = ...,
        err: Any = ...,
        group: bool = ...,
        preexec_fn: Optional[Any] = ...,
    ) -> None: ...
    def alive(self): ...
    def exit_code(self): ...
    def start(self) -> None: ...
    def terminate(self, force: bool = ..., max_retry: int = ...): ...
    def wait(self, timeout: Optional[Any] = ...) -> None: ...



from __future__ import annotations

from typing import Any

from paddle.distributed import collective as collective

ParallelStrategy: Any

def init_parallel_env(): ...
def get_rank(): ...
def get_world_size(): ...



from __future__ import annotations

from typing import Any

from ..fluid import core as core

def Singleton(cls): ...

class OpUpdateInfoHelper:
    def __init__(self, info: Any) -> None: ...
    def verify_key_value(self, name: str = ...): ...

class OpLastCheckpointChecker:
    raw_version_map: Any = ...
    checkpoints_map: Any = ...
    def __init__(self) -> None: ...
    def filter_updates(self, op_name: Any, type: Any = ..., key: str = ...): ...



from __future__ import annotations

from typing import Any, Optional

from ...compiler import CompiledProgram as CompiledProgram

class SerializableBase:
    def serialize(self, path: Any) -> None: ...
    def deserialize(self, path: Any) -> None: ...

class PaddleModel(SerializableBase):
    def __init__(self, exe: Any, program: Any) -> None: ...
    def serialize(self, path: Any) -> None: ...
    def deserialize(self, path: Any) -> None: ...

class CheckpointSaver:
    def __init__(self, fs: Any) -> None: ...
    def save_checkpoint(self, path: Any, slists: Any, trainer_id: Optional[Any] = ..., local_cache_path: str = ...): ...
    def load_checkpoint(
        self,
        path: Any,
        slists: Any,
        trainer_id: Any,
        local_cache_path: str = ...,
        checkpoint_no: Optional[Any] = ...,
        ignore_empty: bool = ...,
    ): ...
    def get_checkpoint_no(self, root_path: Any): ...
    def clean_redundant_checkpoints(self, root_path: Any, reserved: Any = ...) -> None: ...



from __future__ import annotations

from typing import Callable, Optional

from typing_extensions import ParamSpec, TypeVar

from .._typing import Tensor
from .backward_mode import backward as backward
from .py_layer import PyLayer as PyLayer
from .py_layer import PyLayerContext as PyLayerContext

InputArgs = ParamSpec("InputArgs")
RetValue = TypeVar("RetValue")

def grad(
    outputs: Tensor | list[Tensor] | tuple[Tensor],
    inputs: Tensor | list[Tensor] | tuple[Tensor],
    grad_outputs: Optional[Tensor | list[Optional[Tensor]] | tuple[Optional[Tensor], ...]] = ...,
    retain_graph: bool = ...,
    create_graph: bool = ...,
    only_inputs: bool = ...,
    allow_unused: bool = ...,
    no_grad_vars: Optional[Tensor | list[Optional[Tensor]] | tuple[Optional[Tensor], ...]] = None,
): ...
def no_grad(func: Callable[InputArgs, RetValue]) -> Callable[InputArgs, RetValue]: ...



from __future__ import annotations

from typing import Any, Optional

from .streams import Event as Event
from .streams import Stream as Stream

def current_stream(device: Optional[Any] = ...): ...
def synchronize(device: Optional[Any] = ...): ...
def device_count(): ...
def empty_cache() -> None: ...
def max_memory_allocated(device: Optional[Any] = ...): ...
def max_memory_reserved(device: Optional[Any] = ...): ...
def memory_allocated(device: Optional[Any] = ...): ...
def memory_reserved(device: Optional[Any] = ...): ...
def stream_guard(stream: Any) -> None: ...
def get_device_properties(device: Optional[Any] = ...): ...
def get_device_name(device: Optional[Any] = ...): ...
def get_device_capability(device: Optional[Any] = ...): ...



from __future__ import annotations

from enum import IntEnum
from typing import Any

class DeviceType(IntEnum):
    UNKNOWN = ...
    CPU = ...
    GPU = ...
    XPU = ...
    NPU = ...
    DCU = ...
    NIC = ...

class LinkType(IntEnum):
    UNKNOWN = ...
    LOC = ...
    SYS = ...
    PHB = ...
    PIX = ...
    PIB = ...
    NVL = ...
    NVB = ...
    NET = ...

class Device:
    def __init__(self, global_id: Any, local_id: Any, machine: Any) -> None: ...
    @property
    def global_id(self): ...
    @global_id.setter
    def global_id(self, value: Any) -> None: ...
    @property
    def local_id(self): ...
    @local_id.setter
    def local_id(self, value: Any) -> None: ...
    @property
    def machine(self): ...
    @machine.setter
    def machine(self, value: Any) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, value: Any) -> None: ...
    @property
    def model(self): ...
    @model.setter
    def model(self, value: Any) -> None: ...
    @property
    def dp_gflops(self): ...
    @dp_gflops.setter
    def dp_gflops(self, value: Any) -> None: ...
    @property
    def sp_gflops(self): ...
    @sp_gflops.setter
    def sp_gflops(self, value: Any) -> None: ...
    @property
    def memory(self): ...
    @memory.setter
    def memory(self, value: Any) -> None: ...

class Link:
    def __init__(self, source: Any, target: Any) -> None: ...
    @property
    def source(self): ...
    @source.setter
    def source(self, value: Any) -> None: ...
    @property
    def target(self): ...
    @target.setter
    def target(self, value: Any) -> None: ...
    @property
    def type(self): ...
    @type.setter
    def type(self, value: Any) -> None: ...
    @property
    def bandwidth(self): ...
    @bandwidth.setter
    def bandwidth(self, value: Any) -> None: ...
    @property
    def latency(self): ...
    @latency.setter
    def latency(self, value: Any) -> None: ...

class Machine:
    def __init__(self, id: Any) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, value: Any) -> None: ...
    @property
    def hostname(self): ...
    @hostname.setter
    def hostname(self, value: Any) -> None: ...
    @property
    def addr(self): ...
    @addr.setter
    def addr(self, value: Any) -> None: ...
    @property
    def port(self): ...
    @port.setter
    def port(self, value: Any) -> None: ...
    @property
    def devices(self): ...
    @property
    def links(self): ...
    def add_device(self, device: Any) -> None: ...
    def add_link(self, link: Any) -> None: ...

class Cluster:
    def __init__(self) -> None: ...
    @property
    def machines(self): ...
    def add_machine(self, machine: Any) -> None: ...
    def add_device(self, device: Any) -> None: ...
    def add_link(self, link: Any) -> None: ...
    def get_device(self, device_global_id: Any): ...
    def build_from_file(self, json_file_path: Any) -> None: ...
    def get_all_devices(self, device_type: Any): ...
